@@ -125,6 +125,12 @@ protected:
      */
     bool parseFromArgs(CppCheck *cppcheck, int argc, const char* const argv[]);
 
+    /**
+     * Helper function to supply settings. This can be used for testing.
+     * @param settings Reference to an Settings instance
+     */
+    void setSettings(const Settings &settings);
+
 private:
 
     /**
