@@ -202,14 +202,15 @@ simplecpp::TokenList::~TokenList()
     clear();
 }
 
-void simplecpp::TokenList::operator=(const TokenList &other)
+simplecpp::TokenList &simplecpp::TokenList::operator=(const TokenList &other)
 {
-    if (this == &other)
-        return;
-    clear();
-    for (const Token *tok = other.cfront(); tok; tok = tok->next)
-        push_back(new Token(*tok));
-    sizeOfType = other.sizeOfType;
+    if (this != &other) {
+        clear();
+        for (const Token *tok = other.cfront(); tok; tok = tok->next)
+            push_back(new Token(*tok));
+        sizeOfType = other.sizeOfType;
+    }
+    return *this;
 }
 
 void simplecpp::TokenList::clear()
@@ -400,6 +401,20 @@ void simplecpp::TokenList::readfile(std::istream &istr, const std::string &filen
         if (ch < ' ' && ch != '\t' && ch != '\n' && ch != '\r')
             ch = ' ';
 
+        if (ch >= 0x80) {
+            if (outputList) {
+                simplecpp::Output err(files);
+                err.type = simplecpp::Output::UNHANDLED_CHAR_ERROR;
+                err.location = location;
+                std::ostringstream s;
+                s << (int)ch;
+                err.msg = "The code contains unhandled character(s) (character code=" + s.str() + "). Neither unicode nor extended ascii is supported.";
+                outputList->push_back(err);
+            }
+            clear();
+            return;
+        }
+
         if (ch == '\n') {
             if (cback() && cback()->op == '\\') {
                 if (location.col > cback()->location.col + 1U)
@@ -448,9 +463,12 @@ void simplecpp::TokenList::readfile(std::istream &istr, const std::string &filen
 
         // number or name
         if (isNameChar(ch)) {
+            const bool num = std::isdigit(ch);
             while (istr.good() && isNameChar(ch)) {
                 currentToken += ch;
                 ch = readChar(istr,bom);
+                if (num && ch=='\'' && isNameChar(peekChar(istr,bom)))
+                    ch = readChar(istr,bom);
             }
 
             ungetChar(istr,bom);
@@ -585,6 +603,7 @@ void simplecpp::TokenList::constFold()
         constFoldUnaryNotPosNeg(tok);
         constFoldMulDivRem(tok);
         constFoldAddSub(tok);
+        constFoldShift(tok);
         constFoldComparison(tok);
         constFoldBitwise(tok);
         constFoldLogicalOp(tok);
@@ -765,6 +784,29 @@ void simplecpp::TokenList::constFoldAddSub(Token *tok)
     }
 }
 
+void simplecpp::TokenList::constFoldShift(Token *tok)
+{
+    for (; tok && tok->op != ')'; tok = tok->next) {
+        if (!tok->previous || !tok->previous->number)
+            continue;
+        if (!tok->next || !tok->next->number)
+            continue;
+
+        long long result;
+        if (tok->str == "<<")
+            result = stringToLL(tok->previous->str) << stringToLL(tok->next->str);
+        else if (tok->str == ">>")
+            result = stringToLL(tok->previous->str) >> stringToLL(tok->next->str);
+        else
+            continue;
+
+        tok = tok->previous;
+        tok->setstr(toString(result));
+        deleteToken(tok->next);
+        deleteToken(tok->next);
+    }
+}
+
 static const std::string NOTEQ("not_eq");
 void simplecpp::TokenList::constFoldComparison(Token *tok)
 {
@@ -1023,25 +1065,25 @@ namespace simplecpp {
 
         /**
          * Expand macro. This will recursively expand inner macros.
-         * @param output   destination tokenlist
-         * @param rawtok   macro token
-         * @param macros   list of macros
-         * @param files    the files
+         * @param output     destination tokenlist
+         * @param rawtok     macro token
+         * @param macros     list of macros
+         * @param inputFiles the input files
          * @return token after macro
          * @throw Can throw wrongNumberOfParameters or invalidHashHash
          */
         const Token * expand(TokenList * const output,
                              const Token * rawtok,
                              const std::map<TokenString,Macro> &macros,
-                             std::vector<std::string> &files) const {
+                             std::vector<std::string> &inputFiles) const {
             std::set<TokenString> expandedmacros;
 
-            TokenList output2(files);
+            TokenList output2(inputFiles);
 
             if (functionLike() && rawtok->next && rawtok->next->op == '(') {
                 // Copy macro call to a new tokenlist with no linebreaks
                 const Token * const rawtok1 = rawtok;
-                TokenList rawtokens2(files);
+                TokenList rawtokens2(inputFiles);
                 rawtokens2.push_back(new Token(rawtok->str, rawtok1->location));
                 rawtok = rawtok->next;
                 rawtokens2.push_back(new Token(rawtok->str, rawtok1->location));
@@ -1084,7 +1126,7 @@ namespace simplecpp {
                 const std::map<TokenString,Macro>::const_iterator macro = macros.find(macro2tok->str);
                 if (macro == macros.end() || !macro->second.functionLike())
                     break;
-                TokenList rawtokens2(files);
+                TokenList rawtokens2(inputFiles);
                 const Location loc(macro2tok->location);
                 while (macro2tok) {
                     Token *next = macro2tok->next;
@@ -1191,6 +1233,8 @@ namespace simplecpp {
                     argtok = argtok->next;
                 }
                 if (!sameline(nametoken, argtok)) {
+                    endToken = argtok ? argtok->previous : argtok;
+                    valueToken = NULL;
                     return false;
                 }
                 valueToken = argtok ? argtok->next : NULL;
@@ -1257,8 +1301,8 @@ namespace simplecpp {
                 } else {
                     if (!expandArg(tokens, tok, tok->location, macros, expandedmacros, parametertokens)) {
                         bool expanded = false;
-                        if (macros.find(tok->str) != macros.end() && expandedmacros.find(tok->str) == expandedmacros.end()) {
-                            const std::map<TokenString, Macro>::const_iterator it = macros.find(tok->str);
+                        const std::map<TokenString, Macro>::const_iterator it = macros.find(tok->str);
+                        if (it != macros.end() && expandedmacros.find(tok->str) == expandedmacros.end()) {
                             const Macro &m = it->second;
                             if (!m.functionLike()) {
                                 m.expand(tokens, tok, macros, files);
@@ -1640,7 +1684,7 @@ namespace simplecpp {
             return nextTok;
         }
 
-        bool isReplaced(const std::set<std::string> &expandedmacros) const {
+        static bool isReplaced(const std::set<std::string> &expandedmacros) {
             // return true if size > 1
             std::set<std::string>::const_iterator it = expandedmacros.begin();
             if (it == expandedmacros.end())
@@ -1760,7 +1804,7 @@ static bool isAbsolutePath(const std::string &path)
 {
     if (path.length() >= 3 && path[0] > 0 && std::isalpha(path[0]) && path[1] == ':' && (path[2] == '\\' || path[2] == '/'))
         return true;
-    return path.length() > 1U && (path[0] == '/' || path[0] == '/');
+    return path.length() > 1U && (path[0] == '/' || path[0] == '\\');
 }
 #else
 #define realFilename(f)  f
@@ -1846,16 +1890,20 @@ static void simplifySizeof(simplecpp::TokenList &expr, const std::map<std::strin
             continue;
         simplecpp::Token *tok1 = tok->next;
         if (!tok1) {
-            throw std::runtime_error("missed sizeof argument");
+            throw std::runtime_error("missing sizeof argument");
         }
         simplecpp::Token *tok2 = tok1->next;
         if (!tok2) {
-            throw std::runtime_error("missed sizeof argument");
+            throw std::runtime_error("missing sizeof argument");
         }
         if (tok1->op == '(') {
             tok1 = tok1->next;
-            while (tok2->op != ')')
+            while (tok2->op != ')') {
                 tok2 = tok2->next;
+                if (!tok2) {
+                    throw std::runtime_error("invalid sizeof expression");
+                }
+            }
         }
 
         std::string type;
@@ -2352,12 +2400,14 @@ void simplecpp::preprocess(simplecpp::TokenList &output, const simplecpp::TokenL
                     }
                     try {
                         conditionIsTrue = (evaluate(expr, sizeOfType) != 0);
-                    } catch (const std::exception &) {
+                    } catch (const std::exception &e) {
                         if (outputList) {
                             Output out(rawtok->location.files);
                             out.type = Output::SYNTAX_ERROR;
                             out.location = rawtok->location;
                             out.msg = "failed to evaluate " + std::string(rawtok->str == IF ? "#if" : "#elif") + " condition";
+                            if (e.what() && *e.what())
+                                out.msg += std::string(", ") + e.what();
                             outputList->push_back(out);
                         }
                         output.clear();
