@@ -33,5 +33,5 @@ AboutDialog::AboutDialog(const QString &version, const QString &extraVersion, QW
     mUI.mVersion->setText(mUI.mVersion->text().arg(fmtVersion));
     QString url = "<a href=\"http://cppcheck.net/\">http://cppcheck.net/</a>";
     mUI.mHomepage->setText(mUI.mHomepage->text().arg(url));
-    connect(mUI.mButtons, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(mUI.mButtons, &QDialogButtonBox::accepted, this, &AboutDialog::accept);
 }
