@@ -52,7 +52,7 @@ bool ApplicationList::loadSettings()
     bool succeeded = true;
     if (!names.empty() && !paths.empty() && params.empty()) {
         for (int i = 0; i < paths.length(); i++)
-            params << "";
+            params << QString();
         succeeded = false;
     }
 
