@@ -52,6 +52,30 @@ public:
     */
     void analyseWholeProgram(const QStringList &files);
 
+    void setAddonsAndTools(const QStringList &addonsAndTools) {
+        mAddonsAndTools = addonsAndTools;
+    }
+
+    void setPythonPath(const QString &p) {
+        mPythonPath = p;
+    }
+
+    void setDataDir(const QString &dataDir) {
+        mDataDir = dataDir;
+    }
+
+    void setClangPath(const QString &p) {
+        mClangPath = p;
+    }
+
+    void setClangIncludePaths(const QStringList &s) {
+        mClangIncludePaths = s;
+    }
+
+    void setSuppressions(const QStringList s) {
+        mSuppressions = s;
+    }
+
     /**
     * @brief method that is run in a thread
     *
@@ -94,13 +118,25 @@ protected:
     ThreadResult &mResult;
     /**
     * @brief Cppcheck itself
-    *
     */
     CppCheck mCppcheck;
 
 private:
+    QString getAddonPath() const;
+
+    void runAddonsAndTools(const QString &addonPath, const ImportProject::FileSettings *fileSettings, const QString &fileName);
+
+    void parseAddonErrors(QString err, QString tool);
+    void parseClangErrors(const QString &tool, const QString &file0, QString err);
+
     QStringList mFiles;
     bool mAnalyseWholeProgram;
+    QStringList mAddonsAndTools;
+    QString mPythonPath;
+    QString mDataDir;
+    QString mClangPath;
+    QStringList mClangIncludePaths;
+    QStringList mSuppressions;
 };
 /// @}
 #endif // CHECKTHREAD_H
