@@ -26,10 +26,10 @@
 QString getPath(const QString &type)
 {
     QSettings settings;
-    QString path = settings.value(type, "").toString();
+    QString path = settings.value(type, QString()).toString();
     if (path.isEmpty()) {
         // if not set, fallback to last check path hoping that it will be close enough
-        path = settings.value(SETTINGS_LAST_CHECK_PATH, "").toString();
+        path = settings.value(SETTINGS_LAST_CHECK_PATH, QString()).toString();
         if (path.isEmpty())
             // if not set, return user's home directory as the best we can do for now
             return QDir::homePath();
