@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0">
+<TS version="2.1">
 <context>
     <name>About</name>
     <message>
@@ -29,7 +29,7 @@ of the GNU General Public License version 3</source>
         <source>Visit Cppcheck homepage at %1</source>
         <translation>Cppcheck 홈페이지(%1)를 방문해보세요</translation>
     </message>
-    <message utf8="true">
+    <message>
         <source>Copyright © 2007-2017 Cppcheck team.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -319,27 +319,27 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     <name>LogView</name>
     <message>
         <source>Checking Log</source>
-        <translation>로그 확인</translation>
+        <translation type="vanished">로그 확인</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation>지우기</translation>
+        <translation type="vanished">지우기</translation>
     </message>
     <message>
         <source>Save Log</source>
-        <translation>로그 저장</translation>
+        <translation type="vanished">로그 저장</translation>
     </message>
     <message>
         <source>Text files (*.txt *.log);;All files (*.*)</source>
-        <translation>텍스트 파일 (*.txt *.log);;모든 파일 (*.*)</translation>
+        <translation type="vanished">텍스트 파일 (*.txt *.log);;모든 파일 (*.*)</translation>
     </message>
     <message>
         <source>Cppcheck</source>
-        <translation>Cppcheck</translation>
+        <translation type="vanished">Cppcheck</translation>
     </message>
     <message>
         <source>Could not open file for writing: &quot;%1&quot;</source>
-        <translation>기록할 파일 열기 실패: &quot;%1&quot;</translation>
+        <translation type="vanished">기록할 파일 열기 실패: &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
@@ -366,7 +366,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>&amp;Check</source>
-        <translation>검사(&amp;C)</translation>
+        <translation type="obsolete">검사(&amp;C)</translation>
     </message>
     <message>
         <source>&amp;Edit</source>
@@ -402,7 +402,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Check files</source>
-        <translation>파일 검사</translation>
+        <translation type="obsolete">파일 검사</translation>
     </message>
     <message>
         <source>Ctrl+F</source>
@@ -414,7 +414,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Check directory</source>
-        <translation>디렉토리 검사</translation>
+        <translation type="obsolete">디렉토리 검사</translation>
     </message>
     <message>
         <source>Ctrl+D</source>
@@ -434,7 +434,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Stop checking</source>
-        <translation>검사 중지</translation>
+        <translation type="obsolete">검사 중지</translation>
     </message>
     <message>
         <source>Esc</source>
@@ -462,7 +462,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Style warnings</source>
-        <translation>스타일 경고</translation>
+        <translation type="vanished">스타일 경고</translation>
     </message>
     <message>
         <source>Show style warnings</source>
@@ -470,7 +470,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Errors</source>
-        <translation>에러</translation>
+        <translation type="vanished">에러</translation>
     </message>
     <message>
         <source>Show errors</source>
@@ -558,7 +558,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Warnings</source>
-        <translation>경고</translation>
+        <translation type="vanished">경고</translation>
     </message>
     <message>
         <source>Show warnings</source>
@@ -566,7 +566,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Performance warnings</source>
-        <translation>성능 경고</translation>
+        <translation type="vanished">성능 경고</translation>
     </message>
     <message>
         <source>Show performance warnings</source>
@@ -586,7 +586,7 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Portability</source>
-        <translation>이식성 경고</translation>
+        <translation type="vanished">이식성 경고</translation>
     </message>
     <message>
         <source>Show portability warnings</source>
@@ -622,19 +622,19 @@ Kate로 파일을 열고, 해당 행으로 이동하는 예제:
     </message>
     <message>
         <source>Platforms</source>
-        <translation>플랫폼</translation>
+        <translation type="vanished">플랫폼</translation>
     </message>
     <message>
         <source>C++11</source>
-        <translation>C++11</translation>
+        <translation type="vanished">C++11</translation>
     </message>
     <message>
         <source>C99</source>
-        <translation>C99</translation>
+        <translation type="vanished">C99</translation>
     </message>
     <message>
         <source>Posix</source>
-        <translation>Posix</translation>
+        <translation type="vanished">Posix</translation>
     </message>
     <message>
         <source>Quick Filter:</source>
@@ -650,7 +650,7 @@ Cppcheck 버전간 설정 방법 차이때문인 것으로 보입니다. 편집
     </message>
     <message>
         <source>No suitable files found to check!</source>
-        <translation>검사할 수 있는 파일이 없습니다!</translation>
+        <translation type="obsolete">검사할 수 있는 파일이 없습니다!</translation>
     </message>
     <message>
         <source>You must close the project file before selecting new files or directories!</source>
@@ -658,7 +658,7 @@ Cppcheck 버전간 설정 방법 차이때문인 것으로 보입니다. 편집
     </message>
     <message>
         <source>Select directory to check</source>
-        <translation>검사할 디렉토리 선택</translation>
+        <translation type="obsolete">검사할 디렉토리 선택</translation>
     </message>
     <message>
         <source>Found project file: %1
@@ -672,7 +672,7 @@ Do you want to load this project file instead?</source>
         <source>Found project files from the directory.
 
 Do you want to proceed checking without using any of these project files?</source>
-        <translation>디렉토리에 프로젝트 파일 존재.
+        <translation type="obsolete">디렉토리에 프로젝트 파일 존재.
 
 이 프로젝트 파일을 사용하지 않고 검사를 계속하시겠습니까?</translation>
     </message>
@@ -688,7 +688,7 @@ Do you want to proceed checking without using any of these project files?</sourc
         <source>Checking is running.
 
 Do you want to stop the checking and exit Cppcheck?</source>
-        <translation>검사 중.
+        <translation type="obsolete">검사 중.
 
 검사를 중지하고 Cppcheck을 종료하시겠습니까?</translation>
     </message>
@@ -702,7 +702,7 @@ Do you want to stop the checking and exit Cppcheck?</source>
     </message>
     <message>
         <source>XML files version 2 (*.xml);;XML files version 1 (*.xml);;Text files (*.txt);;CSV files (*.csv)</source>
-        <translation>XML 파일 버전 2 (*.xml);;XML 파일 버전 1 (*.xml);;텍스트 파일 (*.txt);;CSV 파일 (*.csv)</translation>
+        <translation type="obsolete">XML 파일 버전 2 (*.xml);;XML 파일 버전 1 (*.xml);;텍스트 파일 (*.txt);;CSV 파일 (*.csv)</translation>
     </message>
     <message>
         <source>Save the report file</source>
@@ -710,11 +710,11 @@ Do you want to stop the checking and exit Cppcheck?</source>
     </message>
     <message>
         <source>XML files version 1 (*.xml)</source>
-        <translation>XML 파일 버전 1 (*.xml)</translation>
+        <translation type="obsolete">XML 파일 버전 1 (*.xml)</translation>
     </message>
     <message>
         <source>XML files version 2 (*.xml)</source>
-        <translation>XML 파일 버전 2 (*.xml)</translation>
+        <translation type="obsolete">XML 파일 버전 2 (*.xml)</translation>
     </message>
     <message>
         <source>Text files (*.txt)</source>
@@ -782,13 +782,9 @@ Do you want to remove the file from the recently used projects -list?</source>
 Opening a new XML file will clear current results.Do you want to proceed?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Show S&amp;cratchpad...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Select files to check</source>
-        <translation type="unfinished">검사할 파일 선택</translation>
+        <translation type="obsolete">검사할 파일 선택</translation>
     </message>
     <message>
         <source>Cppcheck GUI - Command line parameters</source>
@@ -798,21 +794,17 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>C++ standard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C standard</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>C11</source>
-        <translation type="unfinished">C11</translation>
+        <translation type="obsolete">C11</translation>
     </message>
     <message>
         <source>C89</source>
-        <translation type="unfinished">C89</translation>
+        <translation type="obsolete">C89</translation>
     </message>
     <message>
         <source>C++03</source>
-        <translation type="unfinished">C++03</translation>
+        <translation type="obsolete">C++03</translation>
     </message>
     <message>
         <source>Error</source>
@@ -872,34 +864,10 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>Open a Print Preview Dialog for the Current Results</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Library Editor...</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Open library editor</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Auto-detect language</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enforce C++</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enforce C</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Recheck modified files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Recheck all files</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Unknown element</source>
         <translation type="unfinished"></translation>
@@ -916,18 +884,6 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>Select configuration</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Select the configuration that will be checked</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Deprecated XML format</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>XML format 1 is deprecated and will be removed in cppcheck 1.81.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cppcheck GUI.
 
@@ -953,6 +909,162 @@ Options:
         <source>Build dir &apos;%1&apos; does not exist, create it?</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Analyze files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Analyze directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Reanalyze modified files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop analysis</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>XML files (*.xml);;Text files (*.txt);;CSV files (*.csv)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No suitable files found to analyze!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select files to analyze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select directory to analyze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select the configuration that will be analyzed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Found project files from the directory.
+
+Do you want to proceed analysis without using any of these project files?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Analyzer is running.
+
+Do you want to stop the analysis and exit Cppcheck?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A&amp;nalyze</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;C standard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reanal&amp;yze all files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Style war&amp;nings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>E&amp;rrors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sh&amp;ow Scratchpad...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Warnings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Per&amp;formance warnings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Portability</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Cppcheck results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clang</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Clang results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>P&amp;latforms</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++&amp;11</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C&amp;99</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Posix</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C&amp;11</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;C89</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;C++03</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Library Editor...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Auto-detect language</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Enforce C++</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>E&amp;nforce C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++14</source>
+        <translation type="unfinished">C++14</translation>
+    </message>
+    <message>
+        <source>Failed to import &apos;%1&apos;, analysis is stopped</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Project files (*.cppcheck)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Platforms</name>
@@ -989,15 +1101,15 @@ Options:
     <name>Project</name>
     <message>
         <source>Cppcheck</source>
-        <translation>Cppcheck</translation>
+        <translation type="vanished">Cppcheck</translation>
     </message>
     <message>
         <source>Could not read the project file.</source>
-        <translation>프로젝트 파일을 읽을 수 없습니다.</translation>
+        <translation type="vanished">프로젝트 파일을 읽을 수 없습니다.</translation>
     </message>
     <message>
         <source>Could not write the project file.</source>
-        <translation>프로젝트 파일에 쓸 수 없습니다.</translation>
+        <translation type="vanished">프로젝트 파일에 쓸 수 없습니다.</translation>
     </message>
 </context>
 <context>
@@ -1054,10 +1166,6 @@ Options:
         <source>Exclude</source>
         <translation>Exclude</translation>
     </message>
-    <message>
-        <source>Libraries:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Suppressions</source>
         <translation type="unfinished"></translation>
@@ -1086,28 +1194,72 @@ Options:
         <source>Include Paths:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Root:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;In the build dir, cppcheck stores data about each translation unit.&lt;/p&gt;&lt;p&gt;With a build dir you get whole program analysis.&lt;/p&gt;&lt;p&gt;Unchanged files will be analyzed much faster; Cppcheck skip the analysis of these files and reuse their old data.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Cppcheck build dir (whole program analysis, faster analysis for unchanged files)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Paths and Defines</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Cppcheck can import Visual studio solutions (*.sln), Visual studio projects (*.vcxproj) or compile databases.&lt;/p&gt;&lt;p&gt;Files to check, defines, include paths are imported.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <source>Import Project (Visual studio / compile database)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Import Project (Visual studio / compile database)</source>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;You have a choice:&lt;/p&gt;&lt;p&gt; * Analyze all Debug and Release configurations&lt;/p&gt;&lt;p&gt; * Only analyze the first matching Debug configuration&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Analyze all Visual Studio configurations</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Root path:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning tags (separated by semicolon)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cppcheck build dir (whole program analysis, incremental analysis, statistics, etc)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Libraries</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Addons</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y2038</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Thread safety</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Coding standards</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Extra Tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It is common best practice to use several tools.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clang analyzer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clang-tidy</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1146,7 +1298,7 @@ Options:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Visual Studio (*.sln *.vcxproj);;Compile database (compile_database.json)</source>
+        <source>Visual Studio (*.sln *.vcxproj);;Compile database (compile_commands.json)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1345,6 +1497,22 @@ Please select the directory where file is located.</source>
         <source>note</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Suppress selected id(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tag</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No tag</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Since date</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResultsView</name>
@@ -1406,6 +1574,18 @@ To toggle what kind of errors are shown, open view menu.</source>
         <source>First included by</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>XML format version 1 is no longer supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Analysis Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Warning Details</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ScratchPad</name>
@@ -1458,11 +1638,11 @@ To toggle what kind of errors are shown, open view menu.</source>
     </message>
     <message>
         <source>Paths</source>
-        <translation>경로</translation>
+        <translation type="vanished">경로</translation>
     </message>
     <message>
         <source>Include paths:</source>
-        <translation>Include 경로:</translation>
+        <translation type="vanished">Include 경로:</translation>
     </message>
     <message>
         <source>Add...</source>
@@ -1470,7 +1650,7 @@ To toggle what kind of errors are shown, open view menu.</source>
     </message>
     <message>
         <source>Edit</source>
-        <translation>편집</translation>
+        <translation type="vanished">편집</translation>
     </message>
     <message>
         <source>Remove</source>
@@ -1532,6 +1712,34 @@ To toggle what kind of errors are shown, open view menu.</source>
         <source>Show statistics on check completion</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Addons</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Python binary (leave this empty to use python in the PATH)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clang</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clang path (leave empty to use system PATH)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Visual Studio headers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paths to Visual Studio headers, separated by semicolon &apos;;&apos;.&lt;/p&gt;&lt;p&gt;You can open a Visual Studio command prompt, write &amp;quot;SET INCLUDE&amp;quot;. Then copy/paste the paths.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -1553,12 +1761,20 @@ To toggle what kind of errors are shown, open view menu.</source>
     </message>
     <message>
         <source>Select include directory</source>
-        <translation>Include 디렉토리 선택</translation>
+        <translation type="vanished">Include 디렉토리 선택</translation>
     </message>
     <message>
         <source> [Default]</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select python binary</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select clang path</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatsDialog</name>
@@ -1730,6 +1946,22 @@ To toggle what kind of errors are shown, open view menu.</source>
         <source>Export PDF</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>History</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No cppcheck build dir</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThreadResult</name>
