@@ -33,8 +33,7 @@
 class ThreadHandler;
 class TranslationHandler;
 class ScratchPad;
-class LogView;
-class Project;
+class ProjectFile;
 class ErrorItem;
 class QAction;
 
@@ -63,29 +62,29 @@ public:
     Platforms mPlatforms;
 
     /**
-     * @brief Checks given code
+     * @brief Analyze given code
      *
-     * @param code Content of the (virtual) file to be checked
-     * @param filename Name of the (virtual) file to be checked - determines language.
+     * @param code Content of the (virtual) file to be analyzed
+     * @param filename Name of the (virtual) file to be analyzed - determines language.
      */
-    void checkCode(const QString& code, const QString& filename);
+    void analyzeCode(const QString& code, const QString& filename);
 
 public slots:
 
-    /** @brief Slot for check files menu item */
-    void checkFiles();
+    /** @brief Slot for analyze files menu item */
+    void analyzeFiles();
 
-    /** @brief Slot to recheck all files */
-    void reCheckAll();
+    /** @brief Slot to reanalyze all files */
+    void reAnalyzeAll();
 
     /**
-     * @brief Slot to recheck selected files
+     * @brief Slot to reanalyze selected files
      * @param selectedFilesList list of selected files
      */
     void performSelectedFilesCheck(QStringList selectedFilesList);
 
-    /** @brief Slot to recheck modified files */
-    void reCheckModified();
+    /** @brief Slot to reanalyze modified files */
+    void reAnalyzeModified();
 
     /** @brief Slot to clear all search results */
     void clearResults();
@@ -135,8 +134,8 @@ public slots:
     /** @brief Slot to uncheck all "Show errors" menu items */
     void uncheckAll();
 
-    /** @brief Slot for check directory menu item */
-    void checkDirectory();
+    /** @brief Slot for analyze directory menu item */
+    void analyzeDirectory();
 
     /** @brief Slot to open program's settings dialog */
     void programSettings();
@@ -156,7 +155,7 @@ public slots:
     /** @brief Slot to create new project file */
     void newProjectFile();
 
-    /** @brief Slot to open project file and start checking contained paths. */
+    /** @brief Slot to open project file and start analyzing contained paths. */
     void openProjectFile();
 
     /** @brief Slot to show scratchpad. */
@@ -168,9 +167,6 @@ public slots:
     /** @brief Slot to edit project file. */
     void editProjectFile();
 
-    /** @brief Slot for showing the log view. */
-    void showLogView();
-
     /** @brief Slot for showing the scan and project statistics. */
     void showStatistics();
 
@@ -180,9 +176,9 @@ public slots:
 protected slots:
 
     /** @brief Slot for checkthread's done signal */
-    void checkDone();
+    void analysisDone();
 
-    /** @brief Lock down UI while checking */
+    /** @brief Lock down UI while analyzing */
     void checkLockDownUI();
 
     /** @brief Slot for enabling save and clear button */
@@ -200,44 +196,46 @@ protected slots:
     /** @brief Slot for updating View-menu before it is shown. */
     void aboutToShowViewMenu();
 
-    /** @brief Slot when stop checking button is pressed */
-    void stopChecking();
+    /** @brief Slot when stop analysis button is pressed */
+    void stopAnalysis();
 
     /** @brief Open help file contents */
     void openHelpContents();
 
-    /** @brief Add new line to log. */
-    void log(const QString &logline);
-
-    /** @brief Handle new debug error. */
-    void debugError(const ErrorItem &item);
-
     /** @brief Filters the results in the result list. */
     void filterResults();
 
     /** @brief Opens recently opened project file. */
     void openRecentProject();
 
-    /** @brief Selects the platform as checked platform. */
+    /** @brief Selects the platform as analyzed platform. */
     void selectPlatform();
 
+    /** Some results were tagged */
+    void tagged();
+
+    /** Suppress error ids */
+    void suppressIds(QStringList ids);
+
 private:
 
-    /** @brief Rechecks files */
-    void reCheck(bool all);
+    /** Get filename for last results */
+    QString getLastResults() const;
+
+    /** @brief Reanalyzes files */
+    void reAnalyze(bool all);
 
     /**
-     * @brief Recheck selected files
+     * @brief Reanalyze selected files
      * @param files list of selected files
-     * @param all true if all files of list, false if modified files of list
      */
-    void reCheckSelected(QStringList files, bool all);
+    void reAnalyzeSelected(QStringList files);
 
     /**
-      * @brief Check the project.
-      * @param project Pointer to the project to check.
+      * @brief Analyze the project.
+      * @param projectFile Pointer to the project to analyze.
       */
-    void checkProject(Project *project);
+    void analyzeProject(const ProjectFile *projectFile);
 
     /**
      * @brief Set current language
@@ -258,27 +256,27 @@ private:
     void enableCheckButtons(bool enable);
 
     /**
-     * @brief Select files/or directory to check.
+     * @brief Select files/or directory to analyze.
      * Helper function to open a dialog to ask user to select files or
-     * directory to check. Use native dialogs instead of Qt:s own dialogs.
+     * directory to analyze. Use native dialogs instead of Qt:s own dialogs.
      *
      * @param mode Dialog open mode (files or directories)
-     * @return QStringList of files or directories that were selected to check
+     * @return QStringList of files or directories that were selected to analyze
      */
-    QStringList selectFilesToCheck(QFileDialog::FileMode mode);
+    QStringList selectFilesToAnalyze(QFileDialog::FileMode mode);
 
     /**
-     * @brief Check project
+     * @brief Analyze project
      * @param p imported project
      */
-    void doCheckProject(ImportProject p);
+    void doAnalyzeProject(ImportProject p);
 
     /**
-     * @brief Check all files specified in parameter files
+     * @brief Analyze all files specified in parameter files
      *
-     * @param files List of files and/or directories to check
+     * @param files List of files and/or directories to analyze
      */
-    void doCheckFiles(const QStringList &files);
+    void doAnalyzeFiles(const QStringList &files);
 
     /**
      * @brief Get our default cppcheck settings and read project file.
@@ -305,14 +303,14 @@ private:
     /**
      * @brief Enable or disable project file actions.
      * Project editing and closing actions should be only enabled when project is
-     * open and we are not checking files.
+     * open and we are not analyzing files.
      * @param enable If true then actions are enabled.
      */
     void enableProjectActions(bool enable);
 
     /**
      * @brief Enable or disable project file actions.
-     * Project opening and creating actions should be disabled when checking.
+     * Project opening and creating actions should be disabled when analyzing.
      * @param enable If true then actions are enabled.
      */
     void enableProjectOpenActions(bool enable);
@@ -343,6 +341,12 @@ private:
      */
     void loadResults(const QString selectedFile, const QString sourceDirectory);
 
+    /**
+    * @brief Load last project results to the GUI.
+    * @return Returns true if last results was loaded
+    */
+    bool loadLastResults();
+
     /**
      * @brief Load project file to the GUI.
      * @param filePath Filename (inc. path) of project file to load.
@@ -385,7 +389,7 @@ private:
     /** @brief Program settings */
     QSettings *mSettings;
 
-    /** @brief Thread to check files */
+    /** @brief Thread to analyze files */
     ThreadHandler *mThread;
 
     /** @brief List of user defined applications to open errors with */
@@ -397,17 +401,14 @@ private:
     /** @brief Class holding all UI components */
     Ui::MainWindow mUI;
 
-    /** @brief Current checked directory. */
+    /** @brief Current analyzed directory. */
     QString mCurrentDirectory;
 
-    /** @brief Log view. */
-    LogView *mLogView;
-
     /** @brief Scratchpad. */
     ScratchPad* mScratchPad;
 
     /** @brief Project (file). */
-    Project *mProject;
+    ProjectFile *mProjectFile;
 
     /** @brief Filter field in the Filter toolbar. */
     QLineEdit* mLineEditFilter;
@@ -415,7 +416,7 @@ private:
     /** @brief Timer to delay filtering while typing. */
     QTimer* mFilterTimer;
 
-    /** @brief GUI actions for selecting the checked platform. */
+    /** @brief GUI actions for selecting the analyzed platform. */
     QActionGroup *mPlatformActions;
 
     /** @brief GUI actions for selecting the coding standard. */
