@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2015 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2016 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,32 +28,32 @@ PrintableReport::~PrintableReport()
 {
 }
 
-bool PrintableReport::Create()
+bool PrintableReport::create()
 {
     return true;
 }
 
-void PrintableReport::WriteHeader()
+void PrintableReport::writeHeader()
 {
     // No header for printable report
 }
 
-void PrintableReport::WriteFooter()
+void PrintableReport::writeFooter()
 {
     // No footer for printable report
 }
 
-void PrintableReport::WriteError(const ErrorItem &error)
+void PrintableReport::writeError(const ErrorItem &error)
 {
-    const QString file = QDir::toNativeSeparators(error.files[error.files.size() - 1]);
-    QString line = QString("%1,%2,").arg(file).arg(error.lines[error.lines.size() - 1]);
+    const QString file = QDir::toNativeSeparators(error.errorPath.back().file);
+    QString line = QString("%1,%2,").arg(file).arg(error.errorPath.back().line);
     line += QString("%1,%2").arg(GuiSeverity::toString(error.severity)).arg(error.summary);
 
     mFormattedReport += line;
     mFormattedReport += "\n";
 }
 
-QString PrintableReport::GetFormattedReportText() const
+QString PrintableReport::getFormattedReportText() const
 {
     return mFormattedReport;
 }
