@@ -23,12 +23,14 @@
 #include <QFile>
 #include <QDir>
 #include "projectfile.h"
+#include "common.h"
 
 static const char ProjectElementName[] = "project";
 static const char ProjectVersionAttrib[] = "version";
 static const char ProjectFileVersion[] = "1";
 static const char BuildDirElementName[] = "builddir";
 static const char ImportProjectElementName[] = "importproject";
+static const char AnalyzeAllVsConfigsElementName[] = "analyze-all-vs-configs";
 static const char IncludeDirElementName[] = "includedir";
 static const char DirElementName[] = "dir";
 static const char DirNameAttrib[] = "name";
@@ -50,16 +52,41 @@ static const char LibrariesElementName[] = "libraries";
 static const char LibraryElementName[] = "library";
 static const char SuppressionsElementName[] = "suppressions";
 static const char SuppressionElementName[] = "suppression";
+static const char AddonElementName[] = "addon";
+static const char AddonsElementName[] = "addons";
+static const char ToolElementName[] = "tool";
+static const char ToolsElementName[] = "tools";
+static const char TagsElementName[] = "tags";
+static const char TagElementName[] = "tag";
 
 ProjectFile::ProjectFile(QObject *parent) :
     QObject(parent)
 {
+    clear();
 }
 
 ProjectFile::ProjectFile(const QString &filename, QObject *parent) :
     QObject(parent),
     mFilename(filename)
 {
+    clear();
+    read();
+}
+
+void ProjectFile::clear()
+{
+    mRootPath.clear();
+    mBuildDir.clear();
+    mImportProject.clear();
+    mAnalyzeAllVsConfigs = true;
+    mIncludeDirs.clear();
+    mDefines.clear();
+    mPaths.clear();
+    mExcludedPaths.clear();
+    mLibraries.clear();
+    mSuppressions.clear();
+    mAddons.clear();
+    mClangAnalyzer = mClangTidy = false;
 }
 
 bool ProjectFile::read(const QString &filename)
@@ -71,6 +98,8 @@ bool ProjectFile::read(const QString &filename)
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         return false;
 
+    clear();
+
     QXmlStreamReader xmlReader(&file);
     bool insideProject = false;
     bool projectTagFound = false;
@@ -96,6 +125,9 @@ bool ProjectFile::read(const QString &filename)
             if (insideProject && xmlReader.name() == ImportProjectElementName)
                 readImportProject(xmlReader);
 
+            if (insideProject && xmlReader.name() == AnalyzeAllVsConfigsElementName)
+                readAnalyzeAllVsConfigs(xmlReader);
+
             // Find include directory from inside project element
             if (insideProject && xmlReader.name() == IncludeDirElementName)
                 readIncludeDirs(xmlReader);
@@ -121,6 +153,21 @@ bool ProjectFile::read(const QString &filename)
             if (insideProject && xmlReader.name() == SuppressionsElementName)
                 readStringList(mSuppressions, xmlReader,SuppressionElementName);
 
+            // Addons
+            if (insideProject && xmlReader.name() == AddonsElementName)
+                readStringList(mAddons, xmlReader, AddonElementName);
+
+            // Tools
+            if (insideProject && xmlReader.name() == ToolsElementName) {
+                QStringList tools;
+                readStringList(tools, xmlReader, ToolElementName);
+                mClangAnalyzer = tools.contains(CLANG_ANALYZER);
+                mClangTidy = tools.contains(CLANG_TIDY);
+            }
+
+            if (insideProject && xmlReader.name() == TagsElementName)
+                readStringList(mTags, xmlReader, TagElementName);
+
             break;
 
         case QXmlStreamReader::EndElement:
@@ -149,7 +196,7 @@ bool ProjectFile::read(const QString &filename)
 void ProjectFile::readRootPath(QXmlStreamReader &reader)
 {
     QXmlStreamAttributes attribs = reader.attributes();
-    QString name = attribs.value("", RootPathNameAttrib).toString();
+    QString name = attribs.value(QString(), RootPathNameAttrib).toString();
     if (!name.isEmpty())
         mRootPath = name;
 }
@@ -204,6 +251,30 @@ void ProjectFile::readImportProject(QXmlStreamReader &reader)
     } while (1);
 }
 
+void ProjectFile::readAnalyzeAllVsConfigs(QXmlStreamReader &reader)
+{
+    do {
+        const QXmlStreamReader::TokenType type = reader.readNext();
+        switch (type) {
+        case QXmlStreamReader::Characters:
+            mAnalyzeAllVsConfigs = (reader.text().toString() == "true");
+        case QXmlStreamReader::EndElement:
+            return;
+        // Not handled
+        case QXmlStreamReader::StartElement:
+        case QXmlStreamReader::NoToken:
+        case QXmlStreamReader::Invalid:
+        case QXmlStreamReader::StartDocument:
+        case QXmlStreamReader::EndDocument:
+        case QXmlStreamReader::Comment:
+        case QXmlStreamReader::DTD:
+        case QXmlStreamReader::EntityReference:
+        case QXmlStreamReader::ProcessingInstruction:
+            break;
+        }
+    } while (1);
+}
+
 void ProjectFile::readIncludeDirs(QXmlStreamReader &reader)
 {
     QXmlStreamReader::TokenType type;
@@ -216,7 +287,7 @@ void ProjectFile::readIncludeDirs(QXmlStreamReader &reader)
             // Read dir-elements
             if (reader.name().toString() == DirElementName) {
                 QXmlStreamAttributes attribs = reader.attributes();
-                QString name = attribs.value("", DirNameAttrib).toString();
+                QString name = attribs.value(QString(), DirNameAttrib).toString();
                 if (!name.isEmpty())
                     mIncludeDirs << name;
             }
@@ -253,7 +324,7 @@ void ProjectFile::readDefines(QXmlStreamReader &reader)
             // Read define-elements
             if (reader.name().toString() == DefineName) {
                 QXmlStreamAttributes attribs = reader.attributes();
-                QString name = attribs.value("", DefineNameAttrib).toString();
+                QString name = attribs.value(QString(), DefineNameAttrib).toString();
                 if (!name.isEmpty())
                     mDefines << name;
             }
@@ -291,7 +362,7 @@ void ProjectFile::readCheckPaths(QXmlStreamReader &reader)
             // Read dir-elements
             if (reader.name().toString() == PathName) {
                 QXmlStreamAttributes attribs = reader.attributes();
-                QString name = attribs.value("", PathNameAttrib).toString();
+                QString name = attribs.value(QString(), PathNameAttrib).toString();
                 if (!name.isEmpty())
                     mPaths << name;
             }
@@ -328,14 +399,14 @@ void ProjectFile::readExcludes(QXmlStreamReader &reader)
             // Read exclude-elements
             if (reader.name().toString() == ExcludePathName) {
                 QXmlStreamAttributes attribs = reader.attributes();
-                QString name = attribs.value("", ExcludePathNameAttrib).toString();
+                QString name = attribs.value(QString(), ExcludePathNameAttrib).toString();
                 if (!name.isEmpty())
                     mExcludedPaths << name;
             }
             // Read ignore-elements - deprecated but support reading them
             else if (reader.name().toString() == IgnorePathName) {
                 QXmlStreamAttributes attribs = reader.attributes();
-                QString name = attribs.value("", IgnorePathNameAttrib).toString();
+                QString name = attribs.value(QString(), IgnorePathNameAttrib).toString();
                 if (!name.isEmpty())
                     mExcludedPaths << name;
             }
@@ -432,6 +503,11 @@ void ProjectFile::setSuppressions(const QStringList &suppressions)
     mSuppressions = suppressions;
 }
 
+void ProjectFile::setAddons(const QStringList &addons)
+{
+    mAddons = addons;
+}
+
 bool ProjectFile::write(const QString &filename)
 {
     if (!filename.isEmpty())
@@ -465,6 +541,10 @@ bool ProjectFile::write(const QString &filename)
         xmlWriter.writeEndElement();
     }
 
+    xmlWriter.writeStartElement(AnalyzeAllVsConfigsElementName);
+    xmlWriter.writeCharacters(mAnalyzeAllVsConfigs ? "true" : "false");
+    xmlWriter.writeEndElement();
+
     if (!mIncludeDirs.isEmpty()) {
         xmlWriter.writeStartElement(IncludeDirElementName);
         foreach (QString incdir, mIncludeDirs) {
@@ -515,6 +595,23 @@ bool ProjectFile::write(const QString &filename)
                     SuppressionsElementName,
                     SuppressionElementName);
 
+    writeStringList(xmlWriter,
+                    mAddons,
+                    AddonsElementName,
+                    AddonElementName);
+
+    QStringList tools;
+    if (mClangAnalyzer)
+        tools << CLANG_ANALYZER;
+    if (mClangTidy)
+        tools << CLANG_TIDY;
+    writeStringList(xmlWriter,
+                    tools,
+                    ToolsElementName,
+                    ToolElementName);
+
+    writeStringList(xmlWriter, mTags, TagsElementName, TagElementName);
+
     xmlWriter.writeEndDocument();
     file.close();
     return true;
@@ -541,3 +638,13 @@ QStringList ProjectFile::fromNativeSeparators(const QStringList &paths)
         ret << QDir::fromNativeSeparators(path);
     return ret;
 }
+
+QStringList ProjectFile::getAddonsAndTools() const
+{
+    QStringList ret(mAddons);
+    if (mClangAnalyzer)
+        ret << CLANG_ANALYZER;
+    if (mClangTidy)
+        ret << CLANG_TIDY;
+    return ret;
+}
