@@ -62,6 +62,10 @@ public:
         return mImportProject;
     }
 
+    bool getAnalyzeAllVsConfigs() const {
+        return mAnalyzeAllVsConfigs;
+    }
+
     /**
     * @brief Get list of include directories.
     * @return list of directories.
@@ -110,6 +114,40 @@ public:
         return mSuppressions;
     }
 
+    /**
+    * @brief Get list addons.
+    * @return list of addons.
+    */
+    QStringList getAddons() const {
+        return mAddons;
+    }
+
+    /**
+    * @brief Get list of addons and tools.
+    * @return list of addons and tools.
+    */
+    QStringList getAddonsAndTools() const;
+
+    bool getClangAnalyzer() const {
+        return false; //mClangAnalyzer;
+    }
+
+    void setClangAnalyzer(bool c) {
+        mClangAnalyzer = c;
+    }
+
+    bool getClangTidy() const {
+        return mClangTidy;
+    }
+
+    void setClangTidy(bool c) {
+        mClangTidy = c;
+    }
+
+    QStringList getTags() const {
+        return mTags;
+    }
+
     /**
     * @brief Get filename for the project file.
     * @return file name.
@@ -126,7 +164,6 @@ public:
         mRootPath = rootpath;
     }
 
-
     void setBuildDir(const QString &buildDir) {
         mBuildDir = buildDir;
     }
@@ -135,6 +172,10 @@ public:
         mImportProject = importProject;
     }
 
+    void setAnalyzeAllVsConfigs(bool b) {
+        mAnalyzeAllVsConfigs = b;
+    }
+
     /**
      * @brief Set list of includes.
      * @param includes List of defines.
@@ -171,6 +212,20 @@ public:
      */
     void setSuppressions(const QStringList &suppressions);
 
+    /**
+     * @brief Set list of addons.
+     * @param addons List of addons.
+     */
+    void setAddons(const QStringList &addons);
+
+    /**
+     * @brief Set tags.
+     * @param tags tag list
+     */
+    void setTags(const QStringList &tags) {
+        mTags = tags;
+    }
+
     /**
      * @brief Write project file (to disk).
      * @param filename Filename to use.
@@ -201,6 +256,8 @@ protected:
      */
     void readImportProject(QXmlStreamReader &reader);
 
+    void readAnalyzeAllVsConfigs(QXmlStreamReader &reader);
+
     /**
      * @brief Read list of include directories from XML.
      * @param reader XML stream reader.
@@ -244,6 +301,8 @@ protected:
 
 private:
 
+    void clear();
+
     /**
      * @brief Convert paths
      */
@@ -268,6 +327,13 @@ private:
     /** Visual studio project/solution , compile database */
     QString mImportProject;
 
+    /**
+     * Should all visual studio configurations be analyzed?
+     * If this is false then only the Debug configuration
+     * for the set platform is analyzed.
+     */
+    bool mAnalyzeAllVsConfigs;
+
     /**
      * @brief List of include directories used to search include files.
      */
@@ -297,6 +363,22 @@ private:
      * @brief List of suppressions.
      */
     QStringList mSuppressions;
+
+    /**
+     * @brief List of addons.
+     */
+    QStringList mAddons;
+
+    /** @brief Execute clang analyzer? */
+    bool mClangAnalyzer;
+
+    /** @brief Execute clang-tidy? */
+    bool mClangTidy;
+
+    /**
+     * @brief Warning tags
+     */
+    QStringList mTags;
 };
 /// @}
 #endif  // PROJECT_FILE_H
