@@ -32,13 +32,15 @@
 #include "cppcheck.h"
 #include "errorlogger.h"
 
-ProjectFileDialog::ProjectFileDialog(const QString &path, QWidget *parent)
+ProjectFileDialog::ProjectFileDialog(ProjectFile *projectFile, QWidget *parent)
     : QDialog(parent)
-    , mFilePath(path)
+    , mProjectFile(projectFile)
 {
     mUI.setupUi(this);
 
-    const QFileInfo inf(path);
+    mUI.mToolClangAnalyzer->hide();
+
+    const QFileInfo inf(projectFile->getFilename());
     QString filename = inf.fileName();
     QString title = tr("Project file: %1").arg(filename);
     setWindowTitle(title);
@@ -90,23 +92,27 @@ ProjectFileDialog::ProjectFileDialog(const QString &path, QWidget *parent)
         mLibraryCheckboxes << checkbox;
     }
 
-    connect(mUI.mButtons, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(mUI.mBtnBrowseBuildDir, SIGNAL(clicked()), this, SLOT(browseBuildDir()));
-    connect(mUI.mBtnClearImportProject, SIGNAL(clicked(bool)), this, SLOT(clearImportProject()));
-    connect(mUI.mBtnBrowseImportProject, SIGNAL(clicked()), this, SLOT(browseImportProject()));
+    mUI.mEditTags->setValidator(new QRegExpValidator(QRegExp("[a-zA-Z0-9 ;]*"),this));
+
+    connect(mUI.mButtons, &QDialogButtonBox::accepted, this, &ProjectFileDialog::ok);
+    connect(mUI.mBtnBrowseBuildDir, &QPushButton::clicked, this, &ProjectFileDialog::browseBuildDir);
+    connect(mUI.mBtnClearImportProject, &QPushButton::clicked, this, &ProjectFileDialog::clearImportProject);
+    connect(mUI.mBtnBrowseImportProject, &QPushButton::clicked, this, &ProjectFileDialog::browseImportProject);
     connect(mUI.mBtnAddCheckPath, SIGNAL(clicked()), this, SLOT(addCheckPath()));
-    connect(mUI.mBtnEditCheckPath, SIGNAL(clicked()), this, SLOT(editCheckPath()));
-    connect(mUI.mBtnRemoveCheckPath, SIGNAL(clicked()), this, SLOT(removeCheckPath()));
+    connect(mUI.mBtnEditCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::editCheckPath);
+    connect(mUI.mBtnRemoveCheckPath, &QPushButton::clicked, this, &ProjectFileDialog::removeCheckPath);
     connect(mUI.mBtnAddInclude, SIGNAL(clicked()), this, SLOT(addIncludeDir()));
-    connect(mUI.mBtnEditInclude, SIGNAL(clicked()), this, SLOT(editIncludeDir()));
-    connect(mUI.mBtnRemoveInclude, SIGNAL(clicked()), this, SLOT(removeIncludeDir()));
+    connect(mUI.mBtnEditInclude, &QPushButton::clicked, this, &ProjectFileDialog::editIncludeDir);
+    connect(mUI.mBtnRemoveInclude, &QPushButton::clicked, this, &ProjectFileDialog::removeIncludeDir);
     connect(mUI.mBtnAddIgnorePath, SIGNAL(clicked()), this, SLOT(addExcludePath()));
-    connect(mUI.mBtnEditIgnorePath, SIGNAL(clicked()), this, SLOT(editExcludePath()));
-    connect(mUI.mBtnRemoveIgnorePath, SIGNAL(clicked()), this, SLOT(removeExcludePath()));
-    connect(mUI.mBtnIncludeUp, SIGNAL(clicked()), this, SLOT(moveIncludePathUp()));
-    connect(mUI.mBtnIncludeDown, SIGNAL(clicked()), this, SLOT(moveIncludePathDown()));
-    connect(mUI.mBtnAddSuppression, SIGNAL(clicked()), this, SLOT(addSuppression()));
-    connect(mUI.mBtnRemoveSuppression, SIGNAL(clicked()), this, SLOT(removeSuppression()));
+    connect(mUI.mBtnEditIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::editExcludePath);
+    connect(mUI.mBtnRemoveIgnorePath, &QPushButton::clicked, this, &ProjectFileDialog::removeExcludePath);
+    connect(mUI.mBtnIncludeUp, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathUp);
+    connect(mUI.mBtnIncludeDown, &QPushButton::clicked, this, &ProjectFileDialog::moveIncludePathDown);
+    connect(mUI.mBtnAddSuppression, &QPushButton::clicked, this, &ProjectFileDialog::addSuppression);
+    connect(mUI.mBtnRemoveSuppression, &QPushButton::clicked, this, &ProjectFileDialog::removeSuppression);
+
+    loadFromProjectFile(projectFile);
 }
 
 ProjectFileDialog::~ProjectFileDialog()
@@ -136,9 +142,23 @@ void ProjectFileDialog::loadFromProjectFile(const ProjectFile *projectFile)
     setDefines(projectFile->getDefines());
     setCheckPaths(projectFile->getCheckPaths());
     setImportProject(projectFile->getImportProject());
+    mUI.mChkAllVsConfigs->setChecked(projectFile->getAnalyzeAllVsConfigs());
     setExcludedPaths(projectFile->getExcludedPaths());
     setLibraries(projectFile->getLibraries());
     setSuppressions(projectFile->getSuppressions());
+    mUI.mAddonThreadSafety->setChecked(projectFile->getAddons().contains("threadsafety"));
+    mUI.mAddonY2038->setChecked(projectFile->getAddons().contains("y2038"));
+    mUI.mAddonCert->setChecked(projectFile->getAddons().contains("cert"));
+    mUI.mToolClangAnalyzer->setChecked(projectFile->getClangAnalyzer());
+    mUI.mToolClangTidy->setChecked(projectFile->getClangTidy());
+    QString tags;
+    foreach (const QString tag, projectFile->getTags()) {
+        if (tags.isEmpty())
+            tags = tag;
+        else
+            tags += ';' + tag;
+    }
+    mUI.mEditTags->setText(tags);
     updatePathsAndDefines();
 }
 
@@ -147,17 +167,38 @@ void ProjectFileDialog::saveToProjectFile(ProjectFile *projectFile) const
     projectFile->setRootPath(getRootPath());
     projectFile->setBuildDir(getBuildDir());
     projectFile->setImportProject(getImportProject());
+    projectFile->setAnalyzeAllVsConfigs(mUI.mChkAllVsConfigs->isChecked());
     projectFile->setIncludes(getIncludePaths());
     projectFile->setDefines(getDefines());
     projectFile->setCheckPaths(getCheckPaths());
     projectFile->setExcludedPaths(getExcludedPaths());
     projectFile->setLibraries(getLibraries());
     projectFile->setSuppressions(getSuppressions());
+    QStringList list;
+    if (mUI.mAddonThreadSafety->isChecked())
+        list << "threadsafety";
+    if (mUI.mAddonY2038->isChecked())
+        list << "y2038";
+    if (mUI.mAddonCert->isChecked())
+        list << "cert";
+    projectFile->setAddons(list);
+    projectFile->setClangAnalyzer(mUI.mToolClangAnalyzer->isChecked());
+    projectFile->setClangTidy(mUI.mToolClangTidy->isChecked());
+    QStringList tags(mUI.mEditTags->text().split(";"));
+    tags.removeAll(QString());
+    projectFile->setTags(tags);
+}
+
+void ProjectFileDialog::ok()
+{
+    saveToProjectFile(mProjectFile);
+    mProjectFile->write();
+    accept();
 }
 
 QString ProjectFileDialog::getExistingDirectory(const QString &caption, bool trailingSlash)
 {
-    const QFileInfo inf(mFilePath);
+    const QFileInfo inf(mProjectFile->getFilename());
     const QString rootpath = inf.absolutePath();
     QString selectedDir = QFileDialog::getExistingDirectory(this,
                           caption,
@@ -189,9 +230,11 @@ void ProjectFileDialog::browseBuildDir()
 
 void ProjectFileDialog::updatePathsAndDefines()
 {
-    bool importProject = !mUI.mEditImportProject->text().isEmpty();
+    const QString &fileName = mUI.mEditImportProject->text();
+    bool importProject = !fileName.isEmpty();
     mUI.mBtnClearImportProject->setEnabled(importProject);
     mUI.mListCheckPaths->setEnabled(!importProject);
+    mUI.mListIncludeDirs->setEnabled(!importProject);
     mUI.mBtnAddCheckPath->setEnabled(!importProject);
     mUI.mBtnEditCheckPath->setEnabled(!importProject);
     mUI.mBtnRemoveCheckPath->setEnabled(!importProject);
@@ -201,6 +244,7 @@ void ProjectFileDialog::updatePathsAndDefines()
     mUI.mBtnRemoveInclude->setEnabled(!importProject);
     mUI.mBtnIncludeUp->setEnabled(!importProject);
     mUI.mBtnIncludeDown->setEnabled(!importProject);
+    mUI.mChkAllVsConfigs->setEnabled(fileName.endsWith(".sln") || fileName.endsWith(".vcxproj"));
 }
 
 void ProjectFileDialog::clearImportProject()
@@ -211,11 +255,11 @@ void ProjectFileDialog::clearImportProject()
 
 void ProjectFileDialog::browseImportProject()
 {
-    const QFileInfo inf(mFilePath);
+    const QFileInfo inf(mProjectFile->getFilename());
     const QDir &dir = inf.absoluteDir();
     QString fileName = QFileDialog::getOpenFileName(this, tr("Import Project"),
                        dir.canonicalPath(),
-                       tr("Visual Studio (*.sln *.vcxproj);;Compile database (compile_database.json)"));
+                       tr("Visual Studio (*.sln *.vcxproj);;Compile database (compile_commands.json)"));
     if (!fileName.isEmpty()) {
         mUI.mEditImportProject->setText(dir.relativeFilePath(fileName));
         updatePathsAndDefines();
