@@ -47,21 +47,33 @@
 #include "showtypes.h"
 #include "threadhandler.h"
 #include "path.h"
+#include "xmlreportv2.h"
+
+// These must match column headers given in ResultsTree::translate()
+static const unsigned int COLUMN_SINCE_DATE = 6;
+static const unsigned int COLUMN_TAGS       = 7;
 
 ResultsTree::ResultsTree(QWidget * parent) :
     QTreeView(parent),
+    mSettings(nullptr),
+    mApplications(nullptr),
     mContextItem(0),
+    mShowFullPath(false),
+    mSaveFullPath(false),
+    mSaveAllErrors(true),
     mShowErrorId(false),
     mVisibleErrors(false),
-    mSelectionModel(0)
+    mSelectionModel(0),
+    mThread(nullptr),
+    mShowCppcheck(true),
+    mShowClang(true)
 {
     setModel(&mModel);
     translate(); // Adds columns to grid
     setExpandsOnDoubleClick(false);
     setSortingEnabled(true);
 
-    connect(this, SIGNAL(doubleClicked(const QModelIndex &)),
-            this, SLOT(quickStartApplication(const QModelIndex &)));
+    connect(this, &ResultsTree::doubleClicked, this, &ResultsTree::quickStartApplication);
 }
 
 ResultsTree::~ResultsTree()
@@ -118,7 +130,8 @@ bool ResultsTree::addErrorItem(const ErrorItem &item)
         return false;
     }
 
-    QString realfile = stripPath(item.errorPath.back().file, false);
+    const QErrorPathItem &loc = item.errorId.startsWith("clang") ? item.errorPath.front() : item.errorPath.back();
+    QString realfile = stripPath(loc.file, false);
 
     if (realfile.isEmpty()) {
         realfile = tr("Undefined file");
@@ -143,15 +156,17 @@ bool ResultsTree::addErrorItem(const ErrorItem &item)
 
     ErrorLine line;
     line.file = realfile;
-    line.line = item.errorPath.back().line;
+    line.line = loc.line;
     line.errorId = item.errorId;
     line.inconclusive = item.inconclusive;
     line.summary = item.summary;
     line.message = item.message;
     line.severity = item.severity;
+    line.sinceDate = item.sinceDate;
+    line.tags      = item.tags;
     //Create the base item for the error and ensure it has a proper
     //file item as a parent
-    QStandardItem* fileItem = ensureFileItem(item.errorPath.back().file, item.file0, hide);
+    QStandardItem* fileItem = ensureFileItem(loc.file, item.file0, hide);
     QStandardItem* stditem = addBacktraceFiles(fileItem,
                              line,
                              hide,
@@ -167,11 +182,14 @@ bool ResultsTree::addErrorItem(const ErrorItem &item)
     data["severity"]  = ShowTypes::SeverityToShowType(item.severity);
     data["summary"] = item.summary;
     data["message"]  = item.message;
-    data["file"]  = item.errorPath.back().file;
-    data["line"]  = item.errorPath.back().line;
+    data["file"]  = loc.file;
+    data["line"]  = loc.line;
+    data["col"] = loc.col;
     data["id"]  = item.errorId;
     data["inconclusive"] = item.inconclusive;
     data["file0"] = stripPath(item.file0, true);
+    data["sinceDate"] = item.sinceDate;
+    data["tags"] = item.tags;
     stditem->setData(QVariant(data));
 
     //Add backtrace files as children
@@ -197,6 +215,7 @@ bool ResultsTree::addErrorItem(const ErrorItem &item)
             child_data["message"]  = line.message;
             child_data["file"]  = e.file;
             child_data["line"]  = e.line;
+            child_data["col"] = e.col;
             child_data["id"]  = line.errorId;
             child_data["inconclusive"] = line.inconclusive;
             child_item->setData(QVariant(child_data));
@@ -227,7 +246,10 @@ QStandardItem *ResultsTree::addBacktraceFiles(QStandardItem *parent,
          << createLineNumberItem(QString::number(item.line))
          << createNormalItem(childOfMessage ? QString() : item.errorId)
          << (childOfMessage ? createNormalItem(QString()) : createCheckboxItem(item.inconclusive))
-         << createNormalItem(item.summary);
+         << createNormalItem(item.summary)
+         << createNormalItem(item.sinceDate)
+         << createNormalItem(item.tags);
+
     //TODO message has parameter names so we'll need changes to the core
     //cppcheck so we can get proper translations
 
@@ -287,7 +309,7 @@ QString ResultsTree::severityToTranslatedString(Severity::SeverityType severity)
 
     case Severity::none:
     default:
-        return "";
+        return QString();
     }
 }
 
@@ -317,11 +339,11 @@ void ResultsTree::clear(const QString &filename)
     const QString stripped = stripPath(filename, false);
 
     for (int i = 0; i < mModel.rowCount(); ++i) {
-        const QStandardItem *item = mModel.item(i, 0);
-        if (!item)
+        const QStandardItem *fileItem = mModel.item(i, 0);
+        if (!fileItem)
             continue;
 
-        QVariantMap data = item->data().toMap();
+        QVariantMap data = fileItem->data().toMap();
         if (stripped == data["file"].toString() ||
             filename == data["file0"].toString()) {
             mModel.removeRow(i);
@@ -333,12 +355,12 @@ void ResultsTree::clear(const QString &filename)
 void ResultsTree::clearRecheckFile(const QString &filename)
 {
     for (int i = 0; i < mModel.rowCount(); ++i) {
-        const QStandardItem *item = mModel.item(i, 0);
-        if (!item)
+        const QStandardItem *fileItem = mModel.item(i, 0);
+        if (!fileItem)
             continue;
 
         QString actualfile((!mCheckPath.isEmpty() && filename.startsWith(mCheckPath)) ? filename.mid(mCheckPath.length() + 1) : filename);
-        QVariantMap data = item->data().toMap();
+        QVariantMap data = fileItem->data().toMap();
         QString storedfile = data["file"].toString();
         storedfile = ((!mCheckPath.isEmpty() && storedfile.startsWith(mCheckPath)) ? storedfile.mid(mCheckPath.length() + 1) : storedfile);
         if (actualfile == storedfile) {
@@ -380,6 +402,18 @@ void ResultsTree::showResults(ShowTypes::ShowType type, bool show)
     }
 }
 
+void ResultsTree::showCppcheckResults(bool show)
+{
+    mShowCppcheck = show;
+    refreshTree();
+}
+
+void ResultsTree::showClangResults(bool show)
+{
+    mShowClang = show;
+    refreshTree();
+}
+
 void ResultsTree::filterResults(const QString& filter)
 {
     mFilter = filter;
@@ -391,17 +425,17 @@ void ResultsTree::showHiddenResults()
     //Clear the "hide" flag for each item
     int filecount = mModel.rowCount();
     for (int i = 0; i < filecount; i++) {
-        QStandardItem *file = mModel.item(i, 0);
-        if (!file)
+        QStandardItem *fileItem = mModel.item(i, 0);
+        if (!fileItem)
             continue;
 
-        QVariantMap data = file->data().toMap();
+        QVariantMap data = fileItem->data().toMap();
         data["hide"] = false;
-        file->setData(QVariant(data));
+        fileItem->setData(QVariant(data));
 
-        int errorcount = file->rowCount();
+        int errorcount = fileItem->rowCount();
         for (int j = 0; j < errorcount; j++) {
-            QStandardItem *child = file->child(j, 0);
+            QStandardItem *child = fileItem->child(j, 0);
             if (child) {
                 data = child->data().toMap();
                 data["hide"] = false;
@@ -422,20 +456,20 @@ void ResultsTree::refreshTree()
 
     for (int i = 0; i < filecount; i++) {
         //Get file i
-        QStandardItem *file = mModel.item(i, 0);
-        if (!file) {
+        QStandardItem *fileItem = mModel.item(i, 0);
+        if (!fileItem) {
             continue;
         }
 
         //Get the amount of errors this file contains
-        int errorcount = file->rowCount();
+        int errorcount = fileItem->rowCount();
 
         //By default it shouldn't be visible
         bool show = false;
 
         for (int j = 0; j < errorcount; j++) {
             //Get the error itself
-            QStandardItem *child = file->child(j, 0);
+            QStandardItem *child = fileItem->child(j, 0);
             if (!child) {
                 continue;
             }
@@ -458,12 +492,20 @@ void ResultsTree::refreshTree()
                 }
             }
 
+            // Tool filter
+            if (!hide) {
+                if (data["id"].toString().startsWith("clang"))
+                    hide = !mShowClang;
+                else
+                    hide = !mShowCppcheck;
+            }
+
             if (!hide) {
                 mVisibleErrors = true;
             }
 
             //Hide/show accordingly
-            setRowHidden(j, file->index(), hide);
+            setRowHidden(j, fileItem->index(), hide);
 
             //If it was shown then the file itself has to be shown as well
             if (!hide) {
@@ -472,7 +514,7 @@ void ResultsTree::refreshTree()
         }
 
         //Hide the file if its "hide" attribute is set
-        if (file->data().toMap()["hide"].toBool()) {
+        if (fileItem->data().toMap()["hide"].toBool()) {
             show = false;
         }
 
@@ -570,6 +612,7 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             QAction *copymessageid          = new QAction(tr("Copy message id"), &menu);
             QAction *hide                   = new QAction(tr("Hide"), &menu);
             QAction *hideallid              = new QAction(tr("Hide all with id"), &menu);
+            QAction *suppress               = new QAction(tr("Suppress selected id(s)"), &menu);
             QAction *opencontainingfolder   = new QAction(tr("Open containing folder"), &menu);
 
             if (multipleSelection) {
@@ -586,12 +629,16 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
                 recheckSelectedFiles->setDisabled(false);
 
             menu.addAction(recheckSelectedFiles);
+            menu.addSeparator();
             menu.addAction(copyfilename);
             menu.addAction(copypath);
             menu.addAction(copymessage);
             menu.addAction(copymessageid);
+            menu.addSeparator();
             menu.addAction(hide);
             menu.addAction(hideallid);
+            menu.addAction(suppress);
+            menu.addSeparator();
             menu.addAction(opencontainingfolder);
 
             connect(recheckSelectedFiles, SIGNAL(triggered()), this, SLOT(recheckSelectedFiles()));
@@ -601,7 +648,28 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
             connect(copymessageid, SIGNAL(triggered()), this, SLOT(copyMessageId()));
             connect(hide, SIGNAL(triggered()), this, SLOT(hideResult()));
             connect(hideallid, SIGNAL(triggered()), this, SLOT(hideAllIdResult()));
+            connect(suppress, SIGNAL(triggered()), this, SLOT(suppressSelectedIds()));
             connect(opencontainingfolder, SIGNAL(triggered()), this, SLOT(openContainingFolder()));
+
+            if (!mTags.isEmpty()) {
+                menu.addSeparator();
+                QMenu *tagMenu = menu.addMenu(tr("Tag"));
+                {
+                    QAction *action = new QAction(tr("No tag"), tagMenu);
+                    tagMenu->addAction(action);
+                    connect(action, &QAction::triggered, [=]() {
+                        tagSelectedItems(QString());
+                    });
+                }
+
+                foreach (const QString tagstr, mTags) {
+                    QAction *action = new QAction(tagstr, tagMenu);
+                    tagMenu->addAction(action);
+                    connect(action, &QAction::triggered, [=]() {
+                        tagSelectedItems(tagstr);
+                    });
+                }
+            }
         }
 
         //Start the menu
@@ -893,6 +961,43 @@ void ResultsTree::hideAllIdResult()
     }
 }
 
+void ResultsTree::suppressSelectedIds()
+{
+    if (!mSelectionModel)
+        return;
+
+    QModelIndexList selectedRows = mSelectionModel->selectedRows();
+    QSet<QString> selectedIds;
+    foreach (QModelIndex index, selectedRows) {
+        QStandardItem *item = mModel.itemFromIndex(index);
+        if (!item->parent())
+            continue;
+        if (item->parent()->parent())
+            item = item->parent();
+        QVariantMap data = item->data().toMap();
+        if (!data.contains("id"))
+            continue;
+        selectedIds << data["id"].toString();
+    }
+
+    // delete all errors with selected message Ids
+    for (int i = 0; i < mModel.rowCount(); i++) {
+        QStandardItem * const file = mModel.item(i, 0);
+        for (int j = 0; j < file->rowCount();) {
+            QStandardItem *errorItem = file->child(j, 0);
+            QVariantMap userdata = errorItem->data().toMap();
+            if (selectedIds.contains(userdata["id"].toString())) {
+                file->removeRow(j);
+            } else {
+                j++;
+            }
+        }
+    }
+
+
+    emit suppressIds(selectedIds.toList());
+}
+
 void ResultsTree::openContainingFolder()
 {
     QString filePath = getFilePath(mContextItem, true);
@@ -902,6 +1007,25 @@ void ResultsTree::openContainingFolder()
     }
 }
 
+void ResultsTree::tagSelectedItems(const QString &tag)
+{
+    if (!mSelectionModel)
+        return;
+    bool isTagged = false;
+    foreach (QModelIndex index, mSelectionModel->selectedRows()) {
+        QStandardItem *item = mModel.itemFromIndex(index);
+        QVariantMap data = item->data().toMap();
+        if (data.contains("tags")) {
+            data["tags"] = tag;
+            item->setData(QVariant(data));
+            item->parent()->child(index.row(), COLUMN_TAGS)->setText(tag);
+            isTagged = true;
+        }
+    }
+    if (isTagged)
+        emit tagged();
+}
+
 void ResultsTree::context(int application)
 {
     startApplication(mContextItem, application);
@@ -958,7 +1082,7 @@ QString ResultsTree::severityToIcon(Severity::SeverityType severity) const
     case Severity::information:
         return ":images/dialog-information.png";
     default:
-        return "";
+        return QString();
     }
 }
 
@@ -967,70 +1091,132 @@ void ResultsTree::saveResults(Report *report) const
     report->writeHeader();
 
     for (int i = 0; i < mModel.rowCount(); i++) {
-        QStandardItem *item = mModel.item(i, 0);
-        if (!isRowHidden(i, QModelIndex()))
-            saveErrors(report, item);
+        if (mSaveAllErrors || !isRowHidden(i, QModelIndex()))
+            saveErrors(report, mModel.item(i, 0));
     }
 
     report->writeFooter();
 }
 
-void ResultsTree::saveErrors(Report *report, QStandardItem *item) const
+void ResultsTree::saveErrors(Report *report, QStandardItem *fileItem) const
 {
-    if (!item) {
+    if (!fileItem) {
         return;
     }
 
-    for (int i = 0; i < item->rowCount(); i++) {
-        QStandardItem *error = item->child(i, 0);
+    for (int i = 0; i < fileItem->rowCount(); i++) {
+        const QStandardItem *error = fileItem->child(i, 0);
 
         if (!error) {
             continue;
         }
 
-        if (isRowHidden(i, item->index()) && !mSaveAllErrors) {
+        if (isRowHidden(i, fileItem->index()) && !mSaveAllErrors) {
             continue;
         }
 
-        //Get error's user data
-        QVariant userdata = error->data();
-        //Convert it to QVariantMap
-        QVariantMap data = userdata.toMap();
-
         ErrorItem item;
-        item.severity = ShowTypes::ShowTypeToSeverity(ShowTypes::VariantToShowType(data["severity"]));
-        item.summary = data["summary"].toString();
-        item.message = data["message"].toString();
-        item.errorId = data["id"].toString();
-        item.inconclusive = data["inconclusive"].toBool();
-        item.file0 = data["file0"].toString();
-
-        if (error->rowCount() == 0) {
-            QErrorPathItem e;
-            e.file = stripPath(data["file"].toString(), true);
-            e.line = data["line"].toUInt();
-            e.info = data["message"].toString();
-            item.errorPath << e;
-        }
-
-        for (int j = 0; j < error->rowCount(); j++) {
-            QStandardItem *child_error = error->child(j, 0);
-            //Get error's user data
-            QVariant child_userdata = child_error->data();
-            //Convert it to QVariantMap
-            QVariantMap child_data = child_userdata.toMap();
-
-            QErrorPathItem e;
-            e.file = stripPath(child_data["file"].toString(), true);
-            e.line = child_data["line"].toUInt();
-            e.info = child_data["message"].toString();
-            item.errorPath << e;
-        }
+        readErrorItem(error, &item);
 
         report->writeError(item);
     }
 }
 
+static int indexOf(const QList<ErrorItem> &list, const ErrorItem &item)
+{
+    for (int i = 0; i < list.size(); i++) {
+        if (list[i].errorId == item.errorId &&
+            list[i].errorPath == item.errorPath &&
+            list[i].file0 == item.file0 &&
+            list[i].message == item.message &&
+            list[i].inconclusive == item.inconclusive &&
+            list[i].severity == item.severity) {
+            return i;
+        }
+    }
+    return -1;
+}
+
+void ResultsTree::updateFromOldReport(const QString &filename)
+{
+    QList<ErrorItem> oldErrors;
+    XmlReportV2 oldReport(filename);
+    if (oldReport.open()) {
+        oldErrors = oldReport.read();
+        oldReport.close();
+    }
+
+    // Read current results..
+    for (int i = 0; i < mModel.rowCount(); i++) {
+        QStandardItem *fileItem = mModel.item(i,0);
+        for (int j = 0; j < fileItem->rowCount(); j++) {
+            QStandardItem *error = fileItem->child(j,0);
+            ErrorItem errorItem;
+            readErrorItem(error, &errorItem);
+            int oldErrorIndex = indexOf(oldErrors, errorItem);
+            QVariantMap data = error->data().toMap();
+
+            // New error .. set the "sinceDate" property
+            if (oldErrorIndex >= 0 && !oldErrors[oldErrorIndex].sinceDate.isEmpty()) {
+                data["sinceDate"] = oldErrors[oldErrorIndex].sinceDate;
+                error->setData(data);
+                fileItem->child(j, COLUMN_SINCE_DATE)->setText(oldErrors[oldErrorIndex].sinceDate);
+            } else if (oldErrorIndex < 0 || data["sinceDate"].toString().isEmpty()) {
+                const QString sinceDate = QDate::currentDate().toString(Qt::SystemLocaleShortDate);
+                data["sinceDate"] = sinceDate;
+                error->setData(data);
+                fileItem->child(j, COLUMN_SINCE_DATE)->setText(sinceDate);
+                if (oldErrorIndex < 0)
+                    continue;
+            }
+
+            if (!errorItem.tags.isEmpty())
+                continue;
+
+            const ErrorItem &oldErrorItem = oldErrors[oldErrorIndex];
+            data["tags"] = oldErrorItem.tags;
+            error->setData(data);
+        }
+    }
+}
+
+void ResultsTree::readErrorItem(const QStandardItem *error, ErrorItem *item) const
+{
+    // Get error's user data
+    QVariantMap data = error->data().toMap();
+
+    item->severity = ShowTypes::ShowTypeToSeverity(ShowTypes::VariantToShowType(data["severity"]));
+    item->summary = data["summary"].toString();
+    item->message = data["message"].toString();
+    item->errorId = data["id"].toString();
+    item->inconclusive = data["inconclusive"].toBool();
+    item->file0 = data["file0"].toString();
+    item->sinceDate = data["sinceDate"].toString();
+    item->tags = data["tags"].toString();
+
+    if (error->rowCount() == 0) {
+        QErrorPathItem e;
+        e.file = stripPath(data["file"].toString(), true);
+        e.line = data["line"].toUInt();
+        e.info = data["message"].toString();
+        item->errorPath << e;
+    }
+
+    for (int j = 0; j < error->rowCount(); j++) {
+        const QStandardItem *child_error = error->child(j, 0);
+        //Get error's user data
+        QVariant child_userdata = child_error->data();
+        //Convert it to QVariantMap
+        QVariantMap child_data = child_userdata.toMap();
+
+        QErrorPathItem e;
+        e.file = stripPath(child_data["file"].toString(), true);
+        e.line = child_data["line"].toUInt();
+        e.info = child_data["message"].toString();
+        item->errorPath << e;
+    }
+}
+
 void ResultsTree::updateSettings(bool showFullPath,
                                  bool saveFullPath,
                                  bool saveAllErrors,
@@ -1152,7 +1338,7 @@ bool ResultsTree::hasResults() const
 void ResultsTree::translate()
 {
     QStringList labels;
-    labels << tr("File") << tr("Severity") << tr("Line") << tr("Id") << tr("Inconclusive") << tr("Summary");
+    labels << tr("File") << tr("Severity") << tr("Line") << tr("Id") << tr("Inconclusive") << tr("Summary") << tr("Since date") << tr("Tag");
     mModel.setHorizontalHeaderLabels(labels);
     //TODO go through all the errors in the tree and translate severity and message
 }
