@@ -52,6 +52,10 @@ public:
     virtual ~ResultsTree();
     void initialize(QSettings *settings, ApplicationList *list, ThreadHandler *checkThreadHandler);
 
+    void setTags(const QStringList &tags) {
+        mTags = tags;
+    }
+
     /**
     * @brief Add a new item to the tree
     *
@@ -75,15 +79,6 @@ public:
      */
     void clearRecheckFile(const QString &filename);
 
-    /**
-    * @brief Function to show/hide certain type of errors
-    * Refreshes the tree.
-    *
-    * @param type Type of error to show/hide
-    * @param show Should specified errors be shown (true) or hidden (false)
-    */
-    void showResults(ShowTypes::ShowType type, bool show);
-
     /**
     * @brief Function to filter the displayed list of errors.
     * Refreshes the tree.
@@ -103,6 +98,11 @@ public:
     */
     void saveResults(Report *report) const;
 
+    /**
+     * @brief Update items from old report (tag, sinceDate)
+     */
+    void updateFromOldReport(const QString &filename);
+
     /**
     * @brief Update tree settings
     *
@@ -200,6 +200,42 @@ signals:
     */
     void selectionChanged(const QModelIndex &current);
 
+    /**
+     * Selected item(s) has been tagged
+     */
+    void tagged();
+
+    /** Suppress Ids */
+    void suppressIds(QStringList ids);
+
+public slots:
+
+    /**
+    * @brief Function to show/hide certain type of errors
+    * Refreshes the tree.
+    *
+    * @param type Type of error to show/hide
+    * @param show Should specified errors be shown (true) or hidden (false)
+    */
+    void showResults(ShowTypes::ShowType type, bool show);
+
+
+    /**
+    * @brief Show/hide cppcheck errors.
+    * Refreshes the tree.
+    *
+    * @param show Should specified errors be shown (true) or hidden (false)
+    */
+    void showCppcheckResults(bool show);
+
+    /**
+    * @brief Show/hide clang-tidy/clang-analyzer errors.
+    * Refreshes the tree.
+    *
+    * @param show Should specified errors be shown (true) or hidden (false)
+    */
+    void showClangResults(bool show);
+
 protected slots:
     /**
     * @brief Slot to quickstart an error with default application
@@ -257,6 +293,9 @@ protected slots:
     */
     void hideAllIdResult();
 
+    /** Slot for context menu item to suppress all messages with the current message id */
+    void suppressSelectedIds();
+
     /**
     * @brief Slot for context menu item to open the folder containing the current file.
     */
@@ -298,9 +337,9 @@ protected:
     /**
     * @brief Save all errors under specified item
     * @param report Report that errors are saved to
-    * @param item Item whose errors to save
+    * @param fileItem Item whose errors to save
     */
-    void saveErrors(Report *report, QStandardItem *item) const;
+    void saveErrors(Report *report, QStandardItem *fileItem) const;
 
     /**
     * @brief Convert a severity string to a icon filename
@@ -498,8 +537,19 @@ protected:
     bool mVisibleErrors;
 
 private:
+    /** tag selected items */
+    void tagSelectedItems(const QString &tag);
+
+    /** @brief Convert GUI error item into data error item */
+    void readErrorItem(const QStandardItem *error, ErrorItem *item) const;
+
+    QStringList mTags;
+
     QItemSelectionModel *mSelectionModel;
     ThreadHandler *mThread;
+
+    bool mShowCppcheck;
+    bool mShowClang;
 };
 /// @}
 #endif // RESULTSTREE_H
