@@ -27,13 +27,13 @@
 #include <QPrintPreviewDialog>
 #include <QSettings>
 #include <QDir>
+#include <QDate>
 #include "common.h"
 #include "erroritem.h"
 #include "resultsview.h"
 #include "report.h"
 #include "txtreport.h"
 #include "xmlreport.h"
-#include "xmlreportv1.h"
 #include "xmlreportv2.h"
 #include "csvreport.h"
 #include "printablereport.h"
@@ -48,9 +48,17 @@ ResultsView::ResultsView(QWidget * parent) :
 {
     mUI.setupUi(this);
 
-    connect(mUI.mTree, SIGNAL(resultsHidden(bool)), this, SIGNAL(resultsHidden(bool)));
-    connect(mUI.mTree, SIGNAL(checkSelected(QStringList)), this, SIGNAL(checkSelected(QStringList)));
-    connect(mUI.mTree, SIGNAL(selectionChanged(const QModelIndex &)), this, SLOT(updateDetails(const QModelIndex &)));
+    connect(mUI.mTree, &ResultsTree::resultsHidden, this, &ResultsView::resultsHidden);
+    connect(mUI.mTree, &ResultsTree::checkSelected, this, &ResultsView::checkSelected);
+    connect(mUI.mTree, &ResultsTree::selectionChanged, this, &ResultsView::updateDetails);
+    connect(mUI.mTree, &ResultsTree::tagged, this, &ResultsView::tagged);
+    connect(mUI.mTree, &ResultsTree::suppressIds, this, &ResultsView::suppressIds);
+    connect(this, &ResultsView::showResults, mUI.mTree, &ResultsTree::showResults);
+    connect(this, &ResultsView::showCppcheckResults, mUI.mTree, &ResultsTree::showCppcheckResults);
+    connect(this, &ResultsView::showClangResults, mUI.mTree, &ResultsTree::showClangResults);
+    connect(this, &ResultsView::collapseAllResults, mUI.mTree, &ResultsTree::collapseAll);
+    connect(this, &ResultsView::expandAllResults, mUI.mTree, &ResultsTree::expandAll);
+    connect(this, &ResultsView::showHiddenResults, mUI.mTree, &ResultsTree::showHiddenResults);
 }
 
 void ResultsView::initialize(QSettings *settings, ApplicationList *list, ThreadHandler *checkThreadHandler)
@@ -76,7 +84,7 @@ void ResultsView::clear(bool results)
         mUI.mTree->clear();
     }
 
-    mUI.mDetails->setText("");
+    mUI.mDetails->setText(QString());
 
     mStatistics->clear();
 
@@ -106,35 +114,37 @@ void ResultsView::error(const ErrorItem &item)
 {
     if (mUI.mTree->addErrorItem(item)) {
         emit gotResults();
-        mStatistics->addItem(ShowTypes::SeverityToShowType(item.severity));
+        mStatistics->addItem(item.tool(), ShowTypes::SeverityToShowType(item.severity));
     }
 }
 
-void ResultsView::showResults(ShowTypes::ShowType type, bool show)
-{
-    mUI.mTree->showResults(type, show);
-}
-
-void ResultsView::collapseAllResults()
-{
-    mUI.mTree->collapseAll();
-}
-
-void ResultsView::expandAllResults()
-{
-    mUI.mTree->expandAll();
-}
-
-void ResultsView::showHiddenResults()
-{
-    mUI.mTree->showHiddenResults();
-}
-
 void ResultsView::filterResults(const QString& filter)
 {
     mUI.mTree->filterResults(filter);
 }
 
+void ResultsView::saveStatistics(const QString &filename) const
+{
+    QFile f(filename);
+    if (!f.open(QIODevice::Text | QIODevice::Append))
+        return;
+    QTextStream ts(&f);
+    ts <<  '[' << QDate::currentDate().toString("dd.MM.yyyy") << "]\n";
+    ts << QDateTime::currentMSecsSinceEpoch() << '\n';
+    foreach (QString tool, mStatistics->getTools()) {
+        ts << tool << "-error:" << mStatistics->getCount(tool, ShowTypes::ShowErrors) << '\n';
+        ts << tool << "-warning:" << mStatistics->getCount(tool, ShowTypes::ShowWarnings) << '\n';
+        ts << tool << "-style:" << mStatistics->getCount(tool, ShowTypes::ShowStyle) << '\n';
+        ts << tool << "-performance:" << mStatistics->getCount(tool, ShowTypes::ShowPerformance) << '\n';
+        ts << tool << "-portability:" << mStatistics->getCount(tool, ShowTypes::ShowPortability) << '\n';
+    }
+}
+
+void ResultsView::updateFromOldReport(const QString &filename) const
+{
+    mUI.mTree->updateFromOldReport(filename);
+}
+
 void ResultsView::save(const QString &filename, Report::Type type) const
 {
     if (!hasResults()) {
@@ -153,9 +163,6 @@ void ResultsView::save(const QString &filename, Report::Type type) const
     case Report::TXT:
         report = new TxtReport(filename);
         break;
-    case Report::XML:
-        report = new XmlReportV1(filename);
-        break;
     case Report::XMLV2:
         report = new XmlReportV2(filename);
         break;
@@ -313,12 +320,15 @@ void ResultsView::readErrorsXml(const QString &filename)
         msgBox.exec();
         return;
     }
+    if (version == 1) {
+        QMessageBox msgBox;
+        msgBox.setText(tr("XML format version 1 is no longer supported."));
+        msgBox.setIcon(QMessageBox::Critical);
+        msgBox.exec();
+        return;
+    }
 
-    XmlReport *report = NULL;
-    if (version == 1)
-        report = new XmlReportV1(filename);
-    else if (version == 2)
-        report = new XmlReportV2(filename);
+    XmlReport *report = new XmlReportV2(filename);
 
     QList<ErrorItem> errors;
     if (report) {
@@ -343,7 +353,7 @@ void ResultsView::readErrorsXml(const QString &filename)
     foreach (item, errors) {
         mUI.mTree->addErrorItem(item);
     }
-    mUI.mTree->setCheckDirectory("");
+    mUI.mTree->setCheckDirectory(QString());
 }
 
 void ResultsView::updateDetails(const QModelIndex &index)
@@ -352,7 +362,7 @@ void ResultsView::updateDetails(const QModelIndex &index)
     QStandardItem *item = model->itemFromIndex(index);
 
     if (!item) {
-        mUI.mDetails->setText("");
+        mUI.mDetails->setText(QString());
         return;
     }
 
@@ -364,7 +374,7 @@ void ResultsView::updateDetails(const QModelIndex &index)
 
     // If there is no severity data then it is a parent item without summary and message
     if (!data.contains("severity")) {
-        mUI.mDetails->setText("");
+        mUI.mDetails->setText(QString());
         return;
     }
 
@@ -375,10 +385,20 @@ void ResultsView::updateDetails(const QModelIndex &index)
                            .arg(tr("Message")).arg(message);
 
     const QString file0 = data["file0"].toString();
-    if (file0 != "" && Path::isHeader(data["file"].toString().toStdString()))
+    if (!file0.isEmpty() && Path::isHeader(data["file"].toString().toStdString()))
         formattedMsg += QString("\n\n%1: %2").arg(tr("First included by")).arg(QDir::toNativeSeparators(file0));
 
     if (mUI.mTree->showIdColumn())
         formattedMsg.prepend(tr("Id") + ": " + data["id"].toString() + "\n");
     mUI.mDetails->setText(formattedMsg);
 }
+
+void ResultsView::log(const QString &str)
+{
+    mUI.mListLog->addItem(str);
+}
+
+void ResultsView::debugError(const ErrorItem &item)
+{
+    mUI.mListLog->addItem(item.ToString());
+}
