@@ -26,7 +26,7 @@ ScratchPad::ScratchPad(MainWindow& mainWindow)
 {
     mUI.setupUi(this);
 
-    connect(mUI.mCheckButton, SIGNAL(clicked()), this, SLOT(checkButtonClicked()));
+    connect(mUI.mCheckButton, &QPushButton::clicked, this, &ScratchPad::checkButtonClicked);
 }
 
 void ScratchPad::checkButtonClicked()
@@ -34,5 +34,5 @@ void ScratchPad::checkButtonClicked()
     QString filename = mUI.lineEdit->text();
     if (filename.isEmpty())
         filename = "test.cpp";
-    mMainWindow.checkCode(mUI.plainTextEdit->toPlainText(), filename);
+    mMainWindow.analyzeCode(mUI.plainTextEdit->toPlainText(), filename);
 }
