@@ -27,29 +27,25 @@ void TestXmlReportV2::readXml()
 {
     const QString filepath(QString(SRCDIR) + "/../data/xmlfiles/xmlreport_v2.xml");
     XmlReportV2 report(filepath);
-    QVERIFY(report.Open());
-    QList<ErrorItem> errors = report.Read();
+    QVERIFY(report.open());
+    QList<ErrorItem> errors = report.read();
     QCOMPARE(errors.size(), 6);
 
-    ErrorItem item = errors[0];
-    QCOMPARE(item.file, QString("test.cxx"));
-    QCOMPARE(item.files.size(), 1);
-    QCOMPARE(item.lines.size(), 1);
-    QCOMPARE(item.files[0], QString("test.cxx"));
-    QCOMPARE(item.lines[0], (unsigned int)11);
+    const ErrorItem &item = errors[0];
+    QCOMPARE(item.errorPath.size(), 1);
+    QCOMPARE(item.errorPath[0].file, QString("test.cxx"));
+    QCOMPARE(item.errorPath[0].line, (unsigned int)11);
     QCOMPARE(item.errorId, QString("unreadVariable"));
     QCOMPARE(GuiSeverity::toString(item.severity), QString("style"));
     QCOMPARE(item.summary, QString("Variable 'a' is assigned a value that is never used"));
     QCOMPARE(item.message, QString("Variable 'a' is assigned a value that is never used"));
 
-    ErrorItem item2 = errors[3];
-    QCOMPARE(item2.file, QString("test.cxx"));
-    QCOMPARE(item2.files.size(), 2);
-    QCOMPARE(item2.lines.size(), 2);
-    QCOMPARE(item2.files[0], QString("test.cxx"));
-    QCOMPARE(item2.lines[0], (unsigned int)32);
-    QCOMPARE(item2.files[1], QString("test.cxx"));
-    QCOMPARE(item2.lines[1], (unsigned int)16);
+    const ErrorItem &item2 = errors[3];
+    QCOMPARE(item2.errorPath.size(), 2);
+    QCOMPARE(item2.errorPath[0].file, QString("test.cxx"));
+    QCOMPARE(item2.errorPath[0].line, (unsigned int)16);
+    QCOMPARE(item2.errorPath[1].file, QString("test.cxx"));
+    QCOMPARE(item2.errorPath[1].line, (unsigned int)32);
     QCOMPARE(item2.errorId, QString("mismatchAllocDealloc"));
     QCOMPARE(GuiSeverity::toString(item2.severity), QString("error"));
     QCOMPARE(item2.summary, QString("Mismatching allocation and deallocation: k"));
