@@ -46,6 +46,8 @@ void ThreadHandler::clearFiles()
     mLastFiles.clear();
     mResults.clearFiles();
     mAnalyseWholeProgram = false;
+    mAddonsAndTools.clear();
+    mSuppressions.clear();
 }
 
 void ThreadHandler::setFiles(const QStringList &files)
@@ -74,7 +76,7 @@ void ThreadHandler::setCheckFiles(QStringList files)
     }
 }
 
-void ThreadHandler::check(const Settings &settings, bool all)
+void ThreadHandler::check(const Settings &settings)
 {
     if (mResults.getFileCount() == 0 || mRunningThreadCount > 0 || settings.jobs == 0) {
         qDebug() << "Can't start checking if there's no files to check or if check is in progress.";
@@ -91,6 +93,12 @@ void ThreadHandler::check(const Settings &settings, bool all)
     }
 
     for (int i = 0; i < mRunningThreadCount; i++) {
+        mThreads[i]->setAddonsAndTools(mAddonsAndTools);
+        mThreads[i]->setPythonPath(mPythonPath);
+        mThreads[i]->setSuppressions(mSuppressions);
+        mThreads[i]->setClangPath(mClangPath);
+        mThreads[i]->setClangIncludePaths(mClangIncludePaths);
+        mThreads[i]->setDataDir(mDataDir);
         mThreads[i]->check(settings);
     }
 
@@ -120,12 +128,11 @@ void ThreadHandler::setThreadCount(const int count)
     //Create new threads
     for (int i = mThreads.size(); i < count; i++) {
         mThreads << new CheckThread(mResults);
-        connect(mThreads.last(), SIGNAL(done()),
-                this, SLOT(threadDone()));
-        connect(mThreads.last(), SIGNAL(fileChecked(const QString &)),
-                &mResults, SLOT(fileChecked(const QString &)));
+        connect(mThreads.last(), &CheckThread::done,
+                this, &ThreadHandler::threadDone);
+        connect(mThreads.last(), &CheckThread::fileChecked,
+                &mResults, &ThreadResult::fileChecked);
     }
-
 }
 
 
@@ -133,11 +140,10 @@ void ThreadHandler::removeThreads()
 {
     for (int i = 0; i < mThreads.size(); i++) {
         mThreads[i]->terminate();
-        disconnect(mThreads.last(), SIGNAL(done()),
-                   this, SLOT(threadDone()));
-        disconnect(mThreads.last(), SIGNAL(fileChecked(const QString &)),
-                   &mResults, SLOT(fileChecked(const QString &)));
-
+        disconnect(mThreads[i], &CheckThread::done,
+                   this, &ThreadHandler::threadDone);
+        disconnect(mThreads[i], &CheckThread::fileChecked,
+                   &mResults, &ThreadResult::fileChecked);
         delete mThreads[i];
     }
 
@@ -178,17 +184,17 @@ void ThreadHandler::stop()
 
 void ThreadHandler::initialize(ResultsView *view)
 {
-    connect(&mResults, SIGNAL(progress(int, const QString&)),
-            view, SLOT(progress(int, const QString&)));
+    connect(&mResults, &ThreadResult::progress,
+            view, &ResultsView::progress);
 
-    connect(&mResults, SIGNAL(error(const ErrorItem &)),
-            view, SLOT(error(const ErrorItem &)));
+    connect(&mResults, &ThreadResult::error,
+            view, &ResultsView::error);
 
-    connect(&mResults, SIGNAL(log(const QString &)),
-            parent(), SLOT(log(const QString &)));
+    connect(&mResults, &ThreadResult::log,
+            this, &ThreadHandler::log);
 
-    connect(&mResults, SIGNAL(debugError(const ErrorItem &)),
-            parent(), SLOT(debugError(const ErrorItem &)));
+    connect(&mResults, &ThreadResult::debugError,
+            this, &ThreadHandler::debugError);
 }
 
 void ThreadHandler::loadSettings(QSettings &settings)
