@@ -71,6 +71,30 @@ public:
     */
     void saveSettings(QSettings &settings) const;
 
+    void setAddonsAndTools(const QStringList &addonsAndTools) {
+        mAddonsAndTools = addonsAndTools;
+    }
+
+    void setSuppressions(const QStringList &s) {
+        mSuppressions = s;
+    }
+
+    void setPythonPath(const QString &p) {
+        mPythonPath = p;
+    }
+
+    void setClangPath(const QString &p) {
+        mClangPath = p;
+    }
+
+    void setClangIncludePaths(const QStringList &s) {
+        mClangIncludePaths = s;
+    }
+
+    void setDataDir(const QString &dataDir) {
+        mDataDir = dataDir;
+    }
+
     /**
     * @brief Clear all files from cppcheck
     *
@@ -95,9 +119,8 @@ public:
     * @brief Start the threads to check the files
     *
     * @param settings Settings for checking
-    * @param all true if all files, false if modified files
     */
-    void check(const Settings &settings, bool all);
+    void check(const Settings &settings);
 
     /**
     * @brief Set files to check
@@ -168,6 +191,10 @@ signals:
     */
     void done();
 
+    void log(const QString &msg);
+
+    void debugError(const ErrorItem &item);
+
 public slots:
 
     /**
@@ -176,9 +203,6 @@ public slots:
     */
     void stop();
 protected slots:
-
-
-
     /**
     * @brief Slot that a single thread is done
     *
@@ -236,6 +260,14 @@ protected:
     int mRunningThreadCount;
 
     bool mAnalyseWholeProgram;
+
+    QStringList mAddonsAndTools;
+    QStringList mSuppressions;
+    QString mPythonPath;
+    QString mClangPath;
+    QStringList mClangIncludePaths;
+
+    QString mDataDir;
 private:
 
     /**
