@@ -98,4 +98,12 @@ int numberOfArguments(const Token *start);
  */
 std::vector<const Token *> getArguments(const Token *ftok);
 
+/**
+ * find lambda function end token
+ * \todo handle explicit return type
+ * \param first The [ token
+ * \return nullptr or the }
+ */
+const Token *findLambdaEndToken(const Token *first);
+
 #endif // astutilsH
