@@ -25,7 +25,7 @@
 //---------------------------------------------------------------------------
 
 Check::Check(const std::string &aname)
-    : _tokenizer(0), _settings(0), _errorLogger(0), _name(aname)
+    : _tokenizer(nullptr), _settings(nullptr), _errorLogger(nullptr), _name(aname)
 {
     for (std::list<Check*>::iterator i = instances().begin(); i != instances().end(); ++i) {
         if ((*i)->name() > aname) {
@@ -38,7 +38,7 @@ Check::Check(const std::string &aname)
 
 void Check::reportError(const ErrorLogger::ErrorMessage &errmsg)
 {
-    std::cout << errmsg.toXML(true, 1) << std::endl;
+    std::cout << errmsg.toXML() << std::endl;
 }
 
 bool Check::wrongData(const Token *tok, bool condition, const char *str)
