@@ -22,6 +22,7 @@
 
 #include "checkautovariables.h"
 
+#include "astutils.h"
 #include "errorlogger.h"
 #include "library.h"
 #include "settings.h"
@@ -38,7 +39,7 @@
 
 // Register this check class into cppcheck by creating a static instance of it..
 namespace {
-    static CheckAutoVariables instance;
+    CheckAutoVariables instance;
 }
 
 static const CWE CWE398(398U);  // Indicator of Poor Code Quality
@@ -438,33 +439,6 @@ static bool astHasAutoResult(const Token *tok)
     return false;
 }
 
-/*!
- * Skip over a lambda expression
- * \return next token - or next token beyond lambda
- * \todo handle explicit return type
- */
-static const Token* skipLambda(const Token* first)
-{
-    if (!first)
-        return nullptr;
-    if (first->str() != "[")
-        return first;
-    const Token* tok = first->link()->next();
-    if (!tok)
-        return nullptr;
-    if (tok->str() == "(") {
-        tok = tok->link()->next();
-    }
-    if (tok->str() == "constexpr")
-        tok = tok->next();
-    if (tok->str() == "mutable")
-        tok = tok->next();
-    if (tok->str() == "{") {
-        tok = tok->link()->next();
-    }
-    return tok;
-}
-
 void CheckAutoVariables::returnReference()
 {
     if (_tokenizer->isC())
@@ -489,9 +463,9 @@ void CheckAutoVariables::returnReference()
                 }
 
                 // Skip over lambdas
-                tok2 = skipLambda(tok2);
-                if (!tok2)
-                    break;
+                const Token *lambdaEndToken = findLambdaEndToken(tok2);
+                if (lambdaEndToken)
+                    tok2 = lambdaEndToken->next();
 
                 if (tok2->str() == "(")
                     tok2 = tok2->link();
