@@ -86,7 +86,7 @@ void CheckBufferOverrun::arrayIndexOutOfBoundsError(const Token *tok, const Arra
     bool inconclusive = false;
     const Token *condition = nullptr;
     for (std::size_t i = 0; i < index.size(); ++i) {
-        inconclusive |= index[i].inconclusive;
+        inconclusive |= index[i].isInconclusive();
         if (condition == nullptr)
             condition = index[i].condition;
     }
@@ -101,7 +101,7 @@ void CheckBufferOverrun::arrayIndexOutOfBoundsError(const Token *tok, const Arra
                     continue;
                 std::string nr;
                 if (index.size() > 1U)
-                    nr = "(" + MathLib::toString(i + 1) + getOrdinalText(i+1) + " array index) ";
+                    nr = "(" + MathLib::toString(i + 1) + getOrdinalText(i + 1) + " array index) ";
                 errorPath.push_back(ErrorPathItem(it->first, nr + info));
             }
         }
@@ -1198,30 +1198,28 @@ void CheckBufferOverrun::checkGlobalAndLocalVariable()
     for (std::list<Scope>::const_iterator scope = symbolDatabase->scopeList.cbegin(); scope != symbolDatabase->scopeList.cend(); ++scope) {
         std::map<unsigned int, ArrayInfo> arrayInfos;
         for (std::list<Variable>::const_iterator var = scope->varlist.cbegin(); var != scope->varlist.cend(); ++var) {
-            if (var->isArray() && var->dimension(0) > 0) {
-                _errorLogger->reportProgress(_tokenizer->list.getSourceFilePath(),
-                                             "Check (BufferOverrun::checkGlobalAndLocalVariable 1)",
-                                             var->nameToken()->progressValue());
+            if (!var->isArray() || var->dimension(0) <= 0)
+                continue;
+            _errorLogger->reportProgress(_tokenizer->list.getSourceFilePath(),
+                                         "Check (BufferOverrun::checkGlobalAndLocalVariable 1)",
+                                         var->nameToken()->progressValue());
 
-                if (_tokenizer->isMaxTime())
-                    return;
+            if (_tokenizer->isMaxTime())
+                return;
 
-                const Token *tok = var->nameToken();
-                do {
-                    if (tok->str() == "{") {
-                        if (Token::simpleMatch(tok->previous(), "= {"))
-                            tok = tok->link();
-                        else
-                            break;
-                    }
-                    tok = tok->next();
-                } while (tok && tok->str() != ";");
-                if (!tok)
-                    break;
-                if (tok->str() == "{")
-                    tok = tok->next();
-                arrayInfos[var->declarationId()] = ArrayInfo(&*var, symbolDatabase, var->declarationId());
-            }
+            const Token *tok = var->nameToken();
+            do {
+                if (tok->str() == "{") {
+                    if (Token::simpleMatch(tok->previous(), "= {"))
+                        tok = tok->link();
+                    else
+                        break;
+                }
+                tok = tok->next();
+            } while (tok && tok->str() != ";");
+            if (!tok)
+                break;
+            arrayInfos[var->declarationId()] = ArrayInfo(&*var, symbolDatabase, var->declarationId());
         }
         if (!arrayInfos.empty())
             checkScope(scope->classStart ? scope->classStart : _tokenizer->tokens(), arrayInfos);
@@ -1301,7 +1299,7 @@ void CheckBufferOverrun::checkGlobalAndLocalVariable()
                 continue;
             }
 
-            if (var == 0)
+            if (var == nullptr)
                 continue;
 
             const MathLib::bigint totalSize = size * static_cast<int>(sizeOfType(var->typeStartToken()));
@@ -1377,17 +1375,9 @@ void CheckBufferOverrun::checkStructVariable()
                         if (Token::Match(tok3->next(), "%var% ;"))
                             varname[0] = &tok3->strAt(1);
 
-                        else if (isArrayOfStruct(tok3,posOfSemicolon)) {
+                        else if (isArrayOfStruct(tok3,posOfSemicolon))
                             varname[0] = &tok3->strAt(1);
 
-                            int pos = 2;
-                            for (int k = 0 ; k < posOfSemicolon; k++) {
-                                for (int index = pos; index < (pos + 3); index++)
-                                    tok3->strAt(index);
-                                pos += 3;
-                            }
-                        }
-
                         // Declare pointer or reference: Fred *fred1
                         else if (Token::Match(tok3->next(), "*|& %var% [,);=]"))
                             varname[0] = &tok3->strAt(2);
@@ -1674,23 +1664,25 @@ void CheckBufferOverrun::checkBufferAllocatedWithStrlen()
         const Scope * scope = symbolDatabase->functionScopes[i];
         for (const Token *tok = scope->classStart->next(); tok && tok != scope->classEnd; tok = tok->next()) {
             unsigned int dstVarId = tok->varId();
-            unsigned int srcVarId;
-
             if (!dstVarId || tok->strAt(1) != "=")
                 continue;
 
             tok = tok->tokAt(2);
 
+            unsigned int srcVarId;
             // Look for allocation of a buffer based on the size of a string
             if (Token::Match(tok, "malloc|g_malloc|g_try_malloc|alloca ( strlen ( %var% ) )")) {
-                srcVarId = tok->tokAt(4)->varId();
-                tok      = tok->tokAt(6);
+                const Token *varTok = tok->tokAt(4);
+                srcVarId = varTok->varId();
+                tok      = varTok->tokAt(2);
             } else if (_tokenizer->isCPP() && Token::Match(tok, "new char [ strlen ( %var% ) ]")) {
-                srcVarId = tok->tokAt(5)->varId();
-                tok      = tok->tokAt(7);
+                const Token *varTok = tok->tokAt(5);
+                srcVarId = varTok->varId();
+                tok      = varTok->tokAt(2);
             } else if (Token::Match(tok, "realloc|g_realloc|g_try_realloc ( %name% , strlen ( %var% ) )")) {
-                srcVarId = tok->tokAt(6)->varId();
-                tok      = tok->tokAt(8);
+                const Token *varTok = tok->tokAt(6);
+                srcVarId = varTok->varId();
+                tok      = varTok->tokAt(2);
             } else
                 continue;
 
@@ -1813,7 +1805,7 @@ void CheckBufferOverrun::negativeIndexError(const Token *tok, const ValueFlow::V
                << ", otherwise there is negative array index " << index.intvalue << ".";
     else
         errmsg << "Array index " << index.intvalue << " is out of bounds.";
-    reportError(errorPath, index.errorSeverity() ? Severity::error : Severity::warning, "negativeIndex", errmsg.str(), CWE786, index.inconclusive);
+    reportError(errorPath, index.errorSeverity() ? Severity::error : Severity::warning, "negativeIndex", errmsg.str(), CWE786, index.isInconclusive());
 }
 
 CheckBufferOverrun::ArrayInfo::ArrayInfo()
