@@ -22,8 +22,15 @@
 #define checkpostfixoperatorH
 //---------------------------------------------------------------------------
 
-#include "config.h"
 #include "check.h"
+#include "config.h"
+#include "tokenize.h"
+
+#include <string>
+
+class ErrorLogger;
+class Settings;
+class Token;
 
 /// @addtogroup Checks
 /// @{
