@@ -44,6 +44,7 @@ static const struct CWE CWE628(628U);   // Function Call with Incorrectly Specif
 static const struct CWE CWE664(664U);   // Improper Control of a Resource Through its Lifetime
 static const struct CWE CWE704(704U);   // Incorrect Type Conversion or Cast
 static const struct CWE CWE762(762U);   // Mismatched Memory Management Routines
+static const struct CWE CWE786(786U);   // Access of Memory Location Before Start of Buffer
 static const struct CWE CWE788(788U);   // Access of Memory Location After End of Buffer
 static const struct CWE CWE825(825U);   // Expired Pointer Dereference
 static const struct CWE CWE834(834U);   // Excessive Iteration
@@ -136,8 +137,11 @@ void CheckStl::iterators()
             if (containerAssignScope && tok2 == containerAssignScope->classEnd)
                 container = nullptr; // We don't know which containers might be used with the iterator
 
-            if (tok2 == validatingToken)
+            if (tok2 == validatingToken) {
                 validIterator = true;
+                eraseToken = nullptr;
+                invalidationScope = nullptr;
+            }
 
             // Is iterator compared against different container?
             if (tok2->isComparisonOp() && container && tok2->astOperand1() && tok2->astOperand2()) {
@@ -255,7 +259,7 @@ void CheckStl::iterators()
 
             // bailout handling. Assume that the iterator becomes valid if we see return/break.
             // TODO: better handling
-            else if (Token::Match(tok2, "return|break")) {
+            else if (tok2->scope() == invalidationScope && Token::Match(tok2, "return|break|continue")) {
                 validatingToken = Token::findsimplematch(tok2->next(), ";");
             }
 
@@ -437,6 +441,42 @@ void CheckStl::stlOutOfBoundsError(const Token *tok, const std::string &num, con
         reportError(tok, Severity::error, "stlOutOfBounds", "When " + num + "==" + var + ".size(), " + var + "[" + num + "] is out of bounds.", CWE788, false);
 }
 
+void CheckStl::negativeIndex()
+{
+    // Negative index is out of bounds..
+    const SymbolDatabase* const symbolDatabase = _tokenizer->getSymbolDatabase();
+    const std::size_t functions = symbolDatabase->functionScopes.size();
+    for (std::size_t ii = 0; ii < functions; ++ii) {
+        const Scope * scope = symbolDatabase->functionScopes[ii];
+        for (const Token* tok = scope->classStart->next(); tok != scope->classEnd; tok = tok->next()) {
+            if (!Token::Match(tok, "%var% [") || WRONG_DATA(!tok->next()->astOperand2(), tok))
+                continue;
+            const Variable * const var = tok->variable();
+            if (!var || tok == var->nameToken())
+                continue;
+            const Library::Container * const container = _settings->library.detectContainer(var->typeStartToken());
+            if (!container || !container->arrayLike_indexOp)
+                continue;
+            const ValueFlow::Value *index = tok->next()->astOperand2()->getValueLE(-1, _settings);
+            if (!index)
+                continue;
+            negativeIndexError(tok, *index);
+        }
+    }
+}
+
+void CheckStl::negativeIndexError(const Token *tok, const ValueFlow::Value &index)
+{
+    const ErrorPath errorPath = getErrorPath(tok, &index, "Negative array index");
+    std::ostringstream errmsg;
+    if (index.condition)
+        errmsg << ValueFlow::eitherTheConditionIsRedundant(index.condition)
+               << ", otherwise there is negative array index " << index.intvalue << ".";
+    else
+        errmsg << "Array index " << index.intvalue << " is out of bounds.";
+    reportError(errorPath, index.errorSeverity() ? Severity::error : Severity::warning, "negativeContainerIndex", errmsg.str(), CWE786, index.isInconclusive());
+}
+
 void CheckStl::erase()
 {
     const SymbolDatabase* const symbolDatabase = _tokenizer->getSymbolDatabase();
@@ -1055,8 +1095,10 @@ void CheckStl::string_c_str()
                         break;
                     if (!tok2 && j == i->second-1)
                         tok2 = tok->next()->link();
-                    else
+                    else if (tok2)
                         tok2 = tok2->previous();
+                    else
+                        break;
                     if (tok2 && Token::Match(tok2->tokAt(-4), ". c_str|data ( )")) {
                         const Variable* var = tok2->tokAt(-5)->variable();
                         if (var && var->isStlStringType()) {
@@ -1554,6 +1596,17 @@ void CheckStl::readingEmptyStlContainer()
             } else if (tok->str() == "{" && tok->next()->scope()->type == Scope::eLambda)
                 tok = tok->link();
 
+            // function call
+            if (Token::Match(tok, "!!. %name% (") && !Token::simpleMatch(tok->linkAt(2), ") {")) {
+                for (std::map<unsigned int, const Library::Container*>::const_iterator it = emptyContainer.begin(); it != emptyContainer.end();) {
+                    const Variable *var = _tokenizer->getSymbolDatabase()->getVariableFromVarId(it->first);
+                    if (var && (var->isLocal() || var->isArgument()))
+                        ++it;
+                    else
+                        it = emptyContainer.erase(it);
+                }
+            }
+
             if (!tok->varId())
                 continue;
 
@@ -1562,7 +1615,7 @@ void CheckStl::readingEmptyStlContainer()
             if (var && !var->isArrayOrPointer() && !var->typeStartToken()->isStandardType()) {
                 bool insert = false;
                 if (var->nameToken() == tok && var->isLocal() && !var->isStatic()) { // Local variable declared
-                    insert = !Token::Match(tok->next(), "[(=]"); // Only if not initialized
+                    insert = !Token::Match(tok->next(), "[(=:]"); // Only if not initialized
                 } else if (Token::Match(tok, "%var% . clear ( ) ;")) {
                     insert = true;
                 }
