@@ -61,6 +61,7 @@ public:
         CheckStl checkStl(tokenizer, settings, errorLogger);
 
         checkStl.stlOutOfBounds();
+        checkStl.negativeIndex();
         checkStl.iterators();
         checkStl.mismatchingContainers();
         checkStl.erase();
@@ -86,6 +87,11 @@ public:
      */
     void stlOutOfBounds();
 
+    /**
+     * negative index for array like containers
+     */
+    void negativeIndex();
+
     /**
      * Finds errors like this:
      * for (it = foo.begin(); it != bar.end(); ++it)
@@ -171,6 +177,7 @@ private:
     void string_c_strParam(const Token *tok, unsigned int number);
 
     void stlOutOfBoundsError(const Token *tok, const std::string &num, const std::string &var, bool at);
+    void negativeIndexError(const Token *tok, const ValueFlow::Value &index);
     void invalidIteratorError(const Token *tok, const std::string &iteratorName);
     void iteratorsError(const Token *tok, const std::string &container1, const std::string &container2);
     void mismatchingContainersError(const Token *tok);
@@ -203,6 +210,7 @@ private:
         c.mismatchingContainersError(nullptr);
         c.dereferenceErasedError(nullptr, nullptr, "iter");
         c.stlOutOfBoundsError(nullptr, "i", "foo", false);
+        c.negativeIndexError(nullptr, ValueFlow::Value(-1));
         c.invalidIteratorError(nullptr, "push_back|push_front|insert", "iterator");
         c.invalidPointerError(nullptr, "push_back", "pointer");
         c.stlBoundariesError(nullptr);
@@ -212,7 +220,7 @@ private:
         c.string_c_strReturn(nullptr);
         c.string_c_strParam(nullptr, 0);
         c.sizeError(nullptr);
-        c.missingComparisonError(nullptr, 0);
+        c.missingComparisonError(nullptr, nullptr);
         c.redundantIfRemoveError(nullptr);
         c.autoPointerError(nullptr);
         c.autoPointerContainerError(nullptr);
