@@ -62,7 +62,7 @@ public:
                                bool modified = false,
                                bool allocateMemory = false) :
             _var(var),
-            _lastAccess(var?var->nameToken():0),
+            _lastAccess(var ? var->nameToken() : nullptr),
             _type(type),
             _read(read),
             _write(write),
@@ -387,7 +387,7 @@ Variables::VariableUsage *Variables::find(unsigned int varid)
         if (i != _varUsage.end())
             return &i->second;
     }
-    return 0;
+    return nullptr;
 }
 
 void Variables::enterScope()
@@ -431,8 +431,11 @@ void Variables::leaveScope(bool insideLoop)
 static const Token* doAssignment(Variables &variables, const Token *tok, bool dereference, const Scope *scope)
 {
     // a = a + b;
-    if (Token::Match(tok, "%var% = %var% !!;") && tok->varId() == tok->tokAt(2)->varId()) {
-        return tok->tokAt(2);
+    if (Token::Match(tok, "%var% = %var% !!;")) {
+        const Token* rhsVarTok = tok->tokAt(2);
+        if (tok->varId() == rhsVarTok->varId()) {
+            return rhsVarTok;
+        }
     }
 
     if (Token::Match(tok, "%var% %assign%") && tok->strAt(1) != "=")
@@ -629,8 +632,9 @@ static const Token* doAssignment(Variables &variables, const Token *tok, bool de
     // check for alias to struct member
     // char c[10]; a.b = c;
     else if (Token::Match(tok->tokAt(-2), "%name% .")) {
-        if (tok->tokAt(2) && tok->tokAt(2)->varId()) {
-            const unsigned int varid2 = tok->tokAt(2)->varId();
+        const Token *rhsVarTok = tok->tokAt(2);
+        if (rhsVarTok && rhsVarTok->varId()) {
+            const unsigned int varid2 = rhsVarTok->varId();
             const Variables::VariableUsage *var2 = variables.find(varid2);
 
             // struct member aliased to local variable
@@ -920,11 +924,13 @@ void CheckUnusedVar::checkFunctionVariableUsage_iterateScopes(const Scope* const
             (_tokenizer->isCPP() && (Token::Match(tok, "delete %var% ;") || Token::Match(tok, "delete [ ] %var% ;")))) {
             unsigned int varid = 0;
             if (tok->str() != "delete") {
-                varid = tok->tokAt(2)->varId();
-                tok = tok->tokAt(3);
+                const Token *varTok = tok->tokAt(2);
+                varid = varTok->varId();
+                tok = varTok->next();
             } else if (tok->strAt(1) == "[") {
-                varid = tok->tokAt(3)->varId();
-                tok = tok->tokAt(3);
+                const Token *varTok = tok->tokAt(3);
+                varid = varTok->varId();
+                tok = varTok;
             } else {
                 varid = tok->next()->varId();
                 tok = tok->next();
@@ -979,8 +985,10 @@ void CheckUnusedVar::checkFunctionVariableUsage_iterateScopes(const Scope* const
             {
                 const Token *parent = tok->astParent();
                 while (parent) {
-                    if (Token::simpleMatch(parent->previous(), "while ("))
+                    if (Token::simpleMatch(parent->previous(), "while (")) {
                         inwhile = true;
+                        break;
+                    }
                     parent = parent->astParent();
                 }
             }
@@ -1038,7 +1046,8 @@ void CheckUnusedVar::checkFunctionVariableUsage_iterateScopes(const Scope* const
                     else
                         variables.write(varid1, tok);
                 } else if (varid1 && Token::Match(tok, "%varid% .", varid1)) {
-                    variables.use(varid1, tok);
+                    variables.read(varid1, tok);
+                    variables.write(varid1, start);
                 } else if (var &&
                            var->_type == Variables::pointer &&
                            Token::Match(tok, "%name% ;") &&
