@@ -37,7 +37,7 @@ Settings::Settings()
       verbose(false),
       force(false),
       relativePaths(false),
-      xml(false), xml_version(1),
+      xml(false), xml_version(2),
       jobs(1),
       loadAverage(0),
       exitCode(0),
@@ -131,7 +131,7 @@ bool Settings::isEnabled(const ValueFlow::Value *value, bool inconclusiveCheck)
 {
     if (!isEnabled(Settings::WARNING) && (value->condition || value->defaultArg))
         return false;
-    if (!inconclusive && (inconclusiveCheck || value->inconclusive))
+    if (!inconclusive && (inconclusiveCheck || value->isInconclusive()))
         return false;
     return true;
 }
