@@ -36,13 +36,13 @@ struct Standards {
     enum cstd_t { C89, C99, C11, CLatest=C11 } c;
 
     /** C++ code standard */
-    enum cppstd_t { CPP03, CPP11, CPPLatest=CPP11 } cpp;
+    enum cppstd_t { CPP03, CPP11, CPP14, CPPLatest=CPP14 } cpp;
 
     /** Code is posix */
     bool posix;
 
     /** This constructor clear all the variables **/
-    Standards() : c(C11), cpp(CPP11), posix(false) {}
+    Standards() : c(C11), cpp(CPP14), posix(false) {}
 
     bool setC(const std::string& str) {
         if (str == "c89" || str == "C89") {
@@ -68,6 +68,10 @@ struct Standards {
             cpp = CPP11;
             return true;
         }
+        if (str == "c++14" || str == "C++14") {
+            cpp = CPP14;
+            return true;
+        }
         return false;
     }
 };
