@@ -259,12 +259,6 @@ public:
      */
     void simplifyPlatformTypes();
 
-    /**
-     * Collapse compound standard types into a single token.
-     * unsigned long long int => long _isUnsigned=true,_isLong=true
-     */
-    void simplifyStdType();
-
     /**
      * Simplify easy constant '?:' operation
      * Example: 0 ? (2/0) : 0 => 0
