@@ -22,6 +22,7 @@
 //---------------------------------------------------------------------------
 
 #include <algorithm>
+#include <cctype>
 #include <cstddef>
 #include <string>
 
@@ -78,6 +79,19 @@ inline static const char *getOrdinalText(int i)
     return "th";
 }
 
+inline static int caseInsensitiveStringCompare(const std::string &lhs, const std::string &rhs)
+{
+    if (lhs.size() != rhs.size())
+        return (lhs.size() < rhs.size()) ? -1 : 1;
+    for (unsigned int i = 0; i < lhs.size(); ++i) {
+        const int c1 = std::toupper(lhs[i]);
+        const int c2 = std::toupper(rhs[i]);
+        if (c1 != c2)
+            return (c1 < c2) ? -1 : 1;
+    }
+    return 0;
+}
+
 #define UNUSED(x) (void)(x)
 
 #endif
