@@ -37,7 +37,3 @@ ${CPPCHECK} ${CPPCHECK_OPT} ${DIR}std.c
 ${CXX} ${CXX_OPT} ${DIR}std.cpp
 ${CPPCHECK} ${CPPCHECK_OPT} ${DIR}std.cpp
 
-# windows.cpp
-#${CXX} -fsyntax-only ${DIR}windows.cpp
-${CPPCHECK} --check-library --enable=information --enable=style --error-exitcode=1 --inline-suppr --library=windows.cfg ${DIR}windows.cpp
-
