@@ -16,13 +16,20 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "errorlogger.h"
 #include "library.h"
 #include "settings.h"
-#include "token.h"
-#include "tokenlist.h"
-#include "tokenize.h"
+#include "standards.h"
 #include "testsuite.h"
+#include "token.h"
+#include "tokenize.h"
+#include "tokenlist.h"
+
 #include <tinyxml2.h>
+#include <map>
+#include <set>
+#include <string>
+#include <vector>
 
 
 class TestLibrary : public TestFixture {
