@@ -34,7 +34,6 @@ private:
 
     void run() {
         TEST_CASE(checkTooBigShift_Unix32);
-        TEST_CASE(checkTooBigShift_AVR8);
         TEST_CASE(checkIntegerOverflow);
         TEST_CASE(signConversion);
         TEST_CASE(longCastAssign);
@@ -62,67 +61,18 @@ private:
         checkType.runChecks(&tokenizer, settings, this);
     }
 
-    void checkTooBigShift_AVR8() {
-        Settings settings;
-        settings.platform(Settings::AVR8);
-
-        // int, short and size_t on AVR is 2 bytes long
-        {
-            check("int foo(int x) { return x << 17;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 17 bits is undefined behaviour\n", errout.str());
-            check("int foo(int x) { return x << 16;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 16 bits is undefined behaviour\n", errout.str());
-            check("int foo(int x) { return x << 15;}",&settings);
-            ASSERT_EQUALS("", errout.str());
-            check("short foo(int x) { return x << 17;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 17 bits is undefined behaviour\n", errout.str());
-            check("short foo(int x) { return x << 16;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 16 bits is undefined behaviour\n", errout.str());
-            check("short foo(int x) { return x << 15;}",&settings);
-            ASSERT_EQUALS("", errout.str());
-            check("size_t foo(int x) { return x << 17;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 17 bits is undefined behaviour\n", errout.str());
-            check("size_t foo(int x) { return x << 16;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 16 bits is undefined behaviour\n", errout.str());
-            check("size_t foo(int x) { return x << 15;}",&settings);
-            ASSERT_EQUALS("", errout.str());
-        }
-        // long has four 4 bytes long
-        {
-            // downcast to int
-            check("long foo(long x) { return (int)x << 33;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 33 bits is undefined behaviour\n", errout.str());
-            check("long foo(long x) { return x << 33;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 32-bit value by 33 bits is undefined behaviour\n", errout.str());
-            check("long foo(long x) { return x << 32;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 32-bit value by 32 bits is undefined behaviour\n", errout.str());
-            check("long foo(long x) { return x << 31;}",&settings);
-        }
-        // long long is 8 bytes long
-        {
-            // downcast to int
-            check("long long foo(long long x) { return (int)x << 65;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 16-bit value by 65 bits is undefined behaviour\n", errout.str());
-            // downcast to long
-            check("long long foo(long long x) { return (long)x << 65;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 32-bit value by 65 bits is undefined behaviour\n", errout.str());
-            check("long long foo(long long x) { return x << 65;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 64-bit value by 65 bits is undefined behaviour\n", errout.str());
-            check("long long foo(long long x) { return x << 64;}",&settings);
-            ASSERT_EQUALS("[test.cpp:1]: (error) Shifting 64-bit value by 64 bits is undefined behaviour\n", errout.str());
-            check("long long foo(long long x) { return x << 63;}",&settings);
-        }
-    }
-
     void checkTooBigShift_Unix32() {
         Settings settings;
         settings.platform(Settings::Unix32);
 
-        check("int foo(int x) {\n"
+        check("int foo(unsigned int x) {\n"
               "   return x << 32;\n"
               "}",&settings);
         ASSERT_EQUALS("[test.cpp:2]: (error) Shifting 32-bit value by 32 bits is undefined behaviour\n", errout.str());
 
+        check("x = (short)x << 31;",&settings);
+        ASSERT_EQUALS("[test.cpp:1]: (error) Shifting signed 32-bit value by 31 bits is undefined behaviour\n", errout.str());
+
         check("int foo(int x) {\n"
               "   return x << 2;\n"
               "}",&settings);
@@ -140,16 +90,16 @@ private:
         ASSERT_EQUALS("", errout.str());
 
         // Ticket #6793
-        check("template<int I> int foo(int x) { return x << I; }\n"
-              "const int f = foo<31>(0);\n"
-              "const int g = foo<100>(0);\n"
-              "template<int I> int hoo(int x) { return x << 32; }\n"
-              "const int h = hoo<100>(0);", &settings);
+        check("template<unsigned int I> int foo(unsigned int x) { return x << I; }\n"
+              "const unsigned int f = foo<31>(0);\n"
+              "const unsigned int g = foo<100>(0);\n"
+              "template<unsigned int I> int hoo(unsigned int x) { return x << 32; }\n"
+              "const unsigned int h = hoo<100>(0);", &settings);
         ASSERT_EQUALS("[test.cpp:4]: (error) Shifting 32-bit value by 32 bits is undefined behaviour\n"
                       "[test.cpp:1]: (error) Shifting 32-bit value by 100 bits is undefined behaviour\n", errout.str());
 
         // #7266: C++, shift in macro
-        check("void f(int x) {\n"
+        check("void f(unsigned int x) {\n"
               "    UINFO(x << 1234);\n"
               "}");
         ASSERT_EQUALS("", errout.str());
@@ -160,6 +110,12 @@ private:
         settings.platform(Settings::Unix32);
         settings.addEnabled("warning");
 
+        check("x = (int)0x10000 * (int)0x10000;", &settings);
+        ASSERT_EQUALS("[test.cpp:1]: (error) Signed integer overflow for expression '(int)65536*(int)65536'.\n", errout.str());
+
+        check("x = (long)0x10000 * (long)0x10000;", &settings);
+        ASSERT_EQUALS("[test.cpp:1]: (error) Signed integer overflow for expression '(long)65536*(long)65536'.\n", errout.str());
+
         check("void foo() {\n"
               "    int intmax = 0x7fffffff;\n"
               "    return intmax + 1;\n"
@@ -189,14 +145,12 @@ private:
               "   return 123456U * x;\n"
               "}",&settings);
         ASSERT_EQUALS("", errout.str());
-
-        check("int foo() {\n"
-              "  x = 1 << 31;\n" // this is technically integer overflow but it's common code
-              "}", &settings, "test.c");
-        ASSERT_EQUALS("", errout.str());
     }
 
     void signConversion() {
+        check("x = -4 * (unsigned)y;");
+        ASSERT_EQUALS("[test.cpp:1]: (warning) Suspicious code: sign conversion of -4 in calculation because '-4' has a negative value\n", errout.str());
+
         check("unsigned int f1(signed int x, unsigned int y) {" // x is signed
               "  return x * y;\n"
               "}\n"
@@ -281,6 +235,9 @@ private:
     }
 
     void checkFloatToIntegerOverflow() {
+        check("x = (int)1E100;");
+        ASSERT_EQUALS("[test.cpp:1]: (error) Undefined behaviour: float () to integer conversion overflow.\n", removeFloat(errout.str()));
+
         check("void f(void) {\n"
               "  return (int)1E100;\n"
               "}\n");
@@ -305,6 +262,11 @@ private:
               "  return (unsigned char)255.5;\n"
               "}\n");
         ASSERT_EQUALS("", removeFloat(errout.str()));
+
+        check("void f(void) {\n"
+              "  char c = 1234.5;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:2]: (error) Undefined behaviour: float () to integer conversion overflow.\n", removeFloat(errout.str()));
     }
 };
 
